
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
.LANGUAGE C
.NAME     ps2pcl
.PURPOSE  Converts a postscript file in a pcl one.
          */
#define VERSION  "ps2pcl v.0.1"
/*
.COMMENTS Unfortunately ghostscript is required.
----------------------------------------------------------------------------*/


#include <sys/types.h>
#include <sys/stat.h>
#include <stdlib.h>
#include <fcntl.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <time.h>
#include <unistd.h>

extern int errno;

#define TRUE  1
#define FALSE 0
#define OK    1
#define NOK   0

#define CMD_MAX_SIZE (192+8)
#define TOP_MARGIN   0
#define LEFT_MARGIN  (-60)

#define PBM_LINE_LENGTH  64
#define TEMP_FILE "/tmp/cd.pbm"

int GetDimensions ( FILE *, int *, int * );
int ReadLine      ( FILE *, char *, int );
int ZeroesOnly    ( char *, int );
int FirstNonZero  ( char *, int );
int LastNonZero   ( char *, int );


char PRINT_HEADER[] = 
{ 
  /* Send diagnostic */
  0x1b, 0x21, 0x63, 0x32, 0x43, 
  /* Diag data */
  0xff, 0x00, 0x55, 0xaa, 0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80, 
  /* Send media type: 0=generic lacquer coated media */ 
  0x1b, 0x21, 0x74 , 0x30, 0x30, 0x30, 0x43,
  /* CD source ( manual feed ) */
  0x1b, 0x26, 0x6c, 0x30 , 0x48,
  /* Set print Strobe */
  0x1b, 0x21, 0x73, 0x34, 0x30, 0x30, 0x43,
  /* Set raster graphics compression */
  0x1b, 0x2a, 0x62, 0x30, 0x4d
};
char PRINT_TRAILER[] = 
{
  /* Open Drawer */
  0x1b, 0x21, 0x64 , 0x30, 0x43
  /* DON'T FORGET TO PAD LAST "LINE" WITH 0x00 TO THE NEXT 2-BYTE LIMIT ! */
};

int main(argc, argv)
int    argc;
char   **argv;
{
  static void Usage(), PackLine();
  FILE *ip;
  char *inputFile, *outputFile; 
  char tempFile[12];
  char gscmd[128];
  char *aline, *pline, cmd[CMD_MAX_SIZE];
  int rim, n, m, X, Y, y, x;

  strcpy ( tempFile, TEMP_FILE); /* temporary file */
  
  if ( argc < 3) { Usage (); }
  inputFile  = argv[1];
  outputFile = argv[2];

  /* 
   *  Convert PostScript to PCL-5
   *  Here is the tricky part. We will basically call the gs (ghostscript)
   *  program with a pbm output.
   *  Then, we will have to strip off the first bytes and replace them with
   *  the proper sequence for the rimage printer. This is ugly.
   *  A real solution would have been to write a full GS driver for this 
   *  printer. Later, probably? Volunteers wanted.
   */
  
  unlink (outputFile);
  unlink (tempFile);
  sprintf (gscmd, 
	  "echo \"\" | gs -g1700x3400 -r300 -sDEVICE=pbm -sOutputFile=%s %s -q -c quit", tempFile, inputFile);
  
  system (gscmd);
  
  /*
   *  Let us now hack the file: initial suppression of PCL_HEADER_SIZE  bytes 
   */

  ip = fopen (tempFile, "r");
  if ( ip == (FILE *)0 ) 
    {
      perror ("Could not open pbm file");
      return (-1);
    }
  
  rim = open (outputFile, O_WRONLY | O_CREAT  | O_TRUNC, 0644 );
  if ( rim < 0 ) 
   {
     perror ("Could not open output file");
     return (-1);
   }
   
 /* 
  *  Find out the dimensions of the pbm file
  */
 
  GetDimensions ( ip, &X, &Y );
 
  aline = (char *) malloc ( X + 1);
  pline = (char *) malloc ( X/8+1 + 1 );
  
  
  n = write ( rim, PRINT_HEADER, sizeof (PRINT_HEADER) );
  if ( n != sizeof (PRINT_HEADER) ) 
    {
      perror ("Could not write PRINT_HEADER to printer file");
      return (-1);
    }
  
  /*
   *  Now read the PBM file and convert to PCL-5 RIMAGE commands
   */
  y = 1;
  while ( ReadLine ( ip, aline, X ) && y < Y )
    {
    if ( ! ZeroesOnly ( aline, X ) )
    {
      aline [X] = (char )0;
      PackLine ( aline, pline, X);
      sprintf ( cmd, "\033*p%dY", y + TOP_MARGIN );
      n = write (rim, cmd, strlen (cmd));
      if ( n != strlen(cmd) )
      {
        perror ("Could not write 1st command to printer file");
        return (-1);
      }
      x = FirstNonZero ( pline, X );
      m = LastNonZero  ( pline, X/8+1 );
      sprintf (cmd, "\033*p%dX\033*b%dW", x*8+LEFT_MARGIN, m-x+2 );
      n = write (rim, cmd, strlen (cmd));
      if ( n != strlen(cmd) )
      {
        perror ("Could not write 2d & 3d commands to printer file");
        return (-1);
      }
      n = write (rim, &pline[x], m-x+2 );
      if ( n != (m-x+2) )
      {
        perror ("Could not write bitmap to printer file");
        return (-1);
      }
    }
    y++;
  }
  
  n = write ( rim, PRINT_TRAILER, sizeof(PRINT_TRAILER) );
  if ( n != sizeof(PRINT_TRAILER) )
  {
    perror ("Could not write PRINT_TRAILER to printer");
    return (-1);
  }
  close (rim);
  
  return (0);
}


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *  PBM File-related functions
 -------------------------------------------------------------------------*/

int GetDimensions ( ip, x, y )
FILE *ip;
int  *x;
int  *y;
{
  char line[PBM_LINE_LENGTH+1];
  
  /*
   *  Read first identification line (Should be "P1")
   */

  if ( fgets ( line, PBM_LINE_LENGTH, ip ) <= 0 )
  {
    perror ("Could not read PBM file");
    return NOK;
  }
  if ( strncmp (line, "P1", 2 ) )
  {
    perror ("Not a PBM file");
    return NOK;
  }

  /*
   *  Skip  comment line
   */

  fgets ( line, PBM_LINE_LENGTH, ip );

  /*
   *  Read current file dimensions
   */

  fscanf ( ip, "%d %d\n", x, y);

  return OK;
}

int ReadLine ( ip, buf, len )
FILE *ip;
char *buf;
int  len;
{
  int i, nl;
  char *s;

  nl = len/64;
  
  for ( i=0; i<=nl; i++ )
  {
    s = fgets ( &buf[i*PBM_LINE_LENGTH], PBM_LINE_LENGTH+2, ip );
    if ( s == (char *)0 )
    {
      perror( "Could not read a complete PBM file line" );
      return NOK;
    }
  }
  return OK;
}

void PackLine ( ascii, binary, len )
char *ascii;
char *binary;
int  len;
{
  int j,l;
  char *p, *q;

  l = len/8+2;
  memset ( binary, (char)0, l);
  for  ( p = ascii, q = binary; *p; q++, p+=8 )
  {
    for (j = 7; j >= 0; j-- )
    {
      if ( *(p+j) == '1' ) *q |= 1 << (7-j);
    }
  }
}


int ZeroesOnly ( ascii, len )
char *ascii;
int  len;
{
  int flag;
  char *p;

  flag = TRUE;
  for ( p = ascii; *p; p++ )
    if ( *p == '1' ) flag = FALSE;

  return flag;
}


int FirstNonZero ( binary, nbits )
char *binary;
int  nbits;
{

  int i;
  
  for ( i = 0; i < nbits && ! binary[i]; i++ );
    
  return i;
  
}

int LastNonZero ( binary, nbits )
char *binary;
int  nbits;
{

  int i;
  
  for ( i = nbits; i >= 0 && ! binary[i]; i-- );
    
  return i;
}

static void Usage()
{
    printf("Usage: ps2pcl <input file> <output file>\n");
    exit (-1);
}
