#*******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: postArrival.tcl,v 1.1 2004/09/06 14:47:14 cguirao Exp $"
#
# who       when      what
# --------  --------  ----------------------------------------------
# fsogni  01/11/01  created
#

#************************************************************************
#   NAME 
#       postArrival
# 
#   SYNOPSIS
#       postArrival file id
# 
#   DESCRIPTION
#       postArrival gets executed by dhsSubscriber and is applied
#       to each retrieved file.
#     
#   FILES
#
#   ENVIRONMENT
#
#   RETURN VALUES
#       0 if everything went fine
#       1 in case of errors
#
#   CAUTIONS
#
#   EXAMPLES
#
#   SEE ALSO
#
#   BUGS     
#
#------------------------------------------------------------------------
#

#Check the environment variables.
proc checkEnvironment {} {
    global env gvar
    
    if {![info exists env(HOST)]} {
	# can't use the logging facility if the HOST is not defined
	# printing error message to stderr
	puts file2 "Environment variable HOST is not defined"
	exit 1
    } else {
	set gvar(HOST) $env(HOST)
    }
    
    if {![info exists env(ASTO_STAGE_ROOT)]} {
	Log "Environment variable ASTO_STAGE_ROOT is not defined" Error
	exit 1
    }
    
    if {![file exists $env(ASTO_STAGE_ROOT)] || \
	    ![file readable $env(ASTO_STAGE_ROOT)] || \
	    ![file writable $env(ASTO_STAGE_ROOT)]} {
	Log "Can't access ASTO_STAGE_ROOT=$env(ASTO_STAGE_ROOT)" Error
	exit 1
    } else {
	set gvar(ASTO_STAGE_ROOT) $env(ASTO_STAGE_ROOT)
    }
    
    if {[catch {package require Sybtcl}]} { 
	Log "Cannot load package Sybtcl" Error
	exit 1
    }
    
    if {[catch {set gvar(os) [exec uname]} msg]} {
	Log "Cannot determine operative system: $msg" Error
	exit 1
    }
    
    set dbInfo [getDbrcInfo OPCREP]
    set gvar(dbserver) [lindex $dbInfo 0]
    set gvar(dbname) [lindex $dbInfo 1]
    set gvar(dbuser) [lindex $dbInfo 2]
    set gvar(dbpassword) [lindex $dbInfo 3]
}


#Perform a validity check on the arguments
proc checkParameters {} {
    global gvar env argv
    
    if {[llength $argv] != 2} {
	set msg "Usage: postArrival <filename> <media_id>"
	puts $msg
	Log $msg Error
	exit 1
    }
    
    set gvar(file) [lindex $argv 0]
    set gvar(id)   [lindex $argv 1]    
    
    set gvar(filename)    [file tail $gvar(file)]
    set gvar(staging_dir) [file dirname $gvar(file)]
    set gvar(night)       [file tail [file dirname $gvar(file)]]
    set gvar(fileType)    [string trimleft [file extension  $gvar(file)] "."]
    
    if {![file exists $gvar(file)] || \
	    ![file readable $gvar(file)]} {
	Log "File $gvar(file) doesn't exist or is not readable" Error
	exit 1
    }
}


#Core procedure. The one who decide how to segregate a file.
proc storeOnDisk {} {
    global gvar
    
    parseFiletype
    set gvar(target_dir) $gvar(ASTO_STAGE_ROOT)/$gvar(media_stage)/$gvar(night)
    
    Log "Processing $gvar(file)" Info
    if {![isThereDiskSpace $gvar(staging_dir)]} {
	segregate
    } elseif {$gvar(fileType) != "fits"} {
	segregate 
    } elseif {$gvar(progID) == ""} {
	if {[usefulForUsers]} {
	    segregateWithNoDeletion
	} else {
	    segregate
	}
    } elseif {[isVisitor]} {
	segregateWithNoDeletion
    } elseif {$gvar(category) == "SCIENCE"} {
	segregate
    } elseif {[usefulForUsers]} {
	segregateWithNoDeletion
    } else {
	segregate
    }
}


#Segregate a file without removing it.
proc segregateWithNoDeletion {} {
    global gvar
    
    # Log "Segregate file $gvar(filename) under $gvar(target_dir)" Info
    if {![file exists $gvar(target_dir)]} {
	if {[catch {file mkdir $gvar(target_dir)}]} {
	    Log "Can't mkdir $gvar(target_dir)" Error
	    exit 1
	}
    }
    
    if {[catch {exec compress -c $gvar(file) > $gvar(target_dir)/$gvar(filename).Z} msg]} {
	Log "Error copying (compressing) file $gvar(file) to $gvar(target_dir): $msg" Error
	exit 1
    }
}


#Segregate and remove the original file.
proc segregate {} {
    global gvar 
    
    segregateWithNoDeletion
    deleteFile $gvar(file)
}


proc deleteFile {file} {
    # Log "Remove file $file" Info
    if {[catch {file delete $file} msg]} {
	Log "Cannot remove file $file"  Error
	Log "Msg:$msg" Error
	exit 1
    }
}


proc ingestInAsto {} {
    global gvar env
    
    # set cmd "mediaIngest -v -i $gvar(media_id) -f $gvar(night)/$gvar(filename).Z >> $env(DHS_LOG)/mediaIngest.log"
    set num 0
    cd $env(DHS_LOG)
    while {$num < 100} {
	if {[catch {exec mediaIngest -v -i $gvar(media_id) -f $gvar(night)/$gvar(filename).Z >> /dev/null} msg]} {
	    Log "Cannot mediaIngest: $msg" Error
	    set num [expr $num + 1]
	    after 1000
	    continue
	} else {
	    break
	}
    }
    
    if {$num == 100} {
	Log "mediaIngest failed for 100 times" Error
 	Log "mediaIngest -v -i $gvar(media_id) -f $gvar(night)/$gvar(filename).Z" Error
	exit 1 
    }
}


#Determine the type of a file
proc parseFiletype {} {
    global gvar
    set host $gvar(HOST)
    if {[string equal $host "wvgarc"]} {
	# ASTO VLTI
	switch $gvar(fileType) {
	    "fits" {
		set gvar(category) [extractKeyword "DPR CATG"]
		set gvar(progID) [extractKeyword "OBS PROG ID"]
		
		set gvar(media_stage) "19.FITS"
		set gvar(media_id)    19
	    }
	    "log"  {
		set gvar(media_stage)  "13.LOG"
		set gvar(media_id)     13
	    }
	    "paf"  {
		set gvar(media_stage)  "15.PAF"
		set gvar(media_id)     15
	    }
	    default {
		set gvar(media_stage)  "16.OTH"
		set gvar(media_id)     16
	    }
	}
    } else {
	# ASTO VLT
	switch $gvar(fileType) {
	    "fits" {
		set gvar(category) [extractKeyword "DPR CATG"]
		set gvar(progID) [extractKeyword "OBS PROG ID"]
		
		set gvar(media_stage) "9.FITS"
		set gvar(media_id)    9
	    }
	    "log"  {
		set gvar(media_stage)  "3.LOG"
		set gvar(media_id)     3
	    }
	    "paf"  {
		set gvar(media_stage)  "5.PAF"
		set gvar(media_id)     5
	    }
	    default {
		set gvar(media_stage)  "6.OTH"
		set gvar(media_id)     6
	    }
	}
    }
}


#Extract the specified keyword from the file.
proc extractKeyword {keyword} {
    global gvar
    
    if {[catch {$gvar(header)}]} {
	if {[catch {set header [exec slxCatFits $gvar(file)]} msg ]} {
	    Log $msg Error
	    exit 1
	}
	set gvar(header) [split $header "\n"]
    }
    
    set index [lsearch -glob $gvar(header) "*$keyword*"]
    if {$index == "-1"} { return "" }
    set line [lindex $gvar(header) $index]
    set list [split $line "="]
    set key [string trim [lindex [lindex $list 1] 0] "'"]
    return $key
}


#Check the database to see if the file was taken in visitor mode.
proc isVisitor {} {
    global gvar
    
    set sql "select 1 from $gvar(dbname)..sched_rep
where progid like \"%$gvar(progID)%\"
and obs_mode = \"v\""
    set obsMode [Sybsql $sql]
    
    if {$obsMode == ""} {
	return 0
    } else {
	return 1 
    }
}


#Check the database to see if the file can be useful for the user.
proc usefulForUsers {} {
    global gvar
    
    set mjdObsRaw   [extractKeyword MJD-OBS]
    set instrument  [extractKeyword INSTRUME]
    
    set MJD_1970  40587
    set SECS_1970_1980  315532800
    set SECS_DAY  86400
    set eighteenhours 64800
    
    set unixStart [expr int(($mjdObsRaw - $MJD_1970)*86400)]
    set mjdObs    [expr $unixStart - $SECS_1970_1980]
    
    set sql "select distinct 1 from $gvar(dbname)..sched_rep where inst = \"$instrument\" and obs_mode = \"v\" and $mjdObs between (from_date + $eighteenhours) and (to_date + $eighteenhours)"
    
    set isUseful [Sybsql $sql]
    
    if {$isUseful == ""} {
	return 0
    } else {
	return 1 
    }
}


#Increment the counters (used by the gui)
proc incCounters {} {
    global env gvar
    
    incrementCounter $env(DHS_LOG)/.counter-$gvar(id).tmp
    incrementCounter $env(DHS_LOG)/.counter-par-$gvar(id).tmp
}


#################### Main ###############

proc main {} {
    global gvar
    
    set gvar(version) "1.2"
    
    checkEnvironment
    checkParameters
    storeOnDisk
    ingestInAsto
    incCounters
    
    Log "Successfully processed $gvar(file)" Info
    return 0
}

main

##########################################

#
# ___oOo___
