#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# COPYRIGHT (c) 1996 European Southern Observatory
# LICENSE
#
# PROJECT:   VLT Data Flow System
# AUTHOR:    Carlos Guirao - ESO/DMD/SEG
# CI NUMBER: 
#
# $Revision: 1.18 $
#-----------------------------------------------------------------------------

if [ -z "${DATAFLOW_DEV_DIR}" ]; then
  echo "DATAFLOW_DEV_DIR environment not defined"
  return
fi

if [ -z "${DFS_EXTERNAL}" ]; then
  echo "DFS_EXTERNAL environment not defined"
  return
fi

if [ -z "${VLTROOT}" ]; then
  export DFS_VLTROOT=/vlt/JAN2006/NOCCS
else
  export DFS_VLTROOT=${VLTROOT}
fi

export BUILD_ROOT=${DATAFLOW_DEV_DIR}/sniff_data
export INTROOT=${DATAFLOW_DEV_DIR}/INTROOT
export DFS_PLATFORM=`${DATAFLOW_DEV_DIR}/admin/sniff_arch.sh`


# MIDAS
export DFS_MIDAS_PATH=${DFS_EXTERNAL}/midas/05SEP
export DFS_MIDAS_INCL=${DFS_MIDAS_PATH}/incl
export DFS_MIDAS_LIB=${DFS_MIDAS_PATH}/lib/${DFS_PLATFORM}

# VLT OSLX 
if [ -z "$OSLX" ]; then
  export DFS_OSLX=${DFS_VLTROOT}
  export DFS_OSLX_INCL=${DFS_OSLX}/include
  export DFS_OSLX_LIB=${DFS_OSLX}/lib
else
  export DFS_OSLX_INCL=${OSLX}/include
  export DFS_OSLX_LIB=${OSLX}/lib/${DFS_PLATFORM}
fi

# MSQL2
if [ -z "$DFS_MSQL" ]; then
  export DFS_MSQL=/opt/msql2
fi
export DFS_MSQL_INCL=${DFS_MSQL}/include
export DFS_MSQL_LIB=${DFS_MSQL}/lib

# Real Time Display
export DFS_RTD=${DFS_VLTROOT}
export DFS_RTD_INCL=${DFS_RTD}/include/cat
export DFS_RTD_LIB=${DFS_RTD}/lib

# ZLIB package
export DFS_ZLIB=${DFS_EXTERNAL}/zlib
export DFS_ZLIB_INCL=${DFS_ZLIB}/include
export DFS_ZLIB_LIB=${DFS_ZLIB}/lib/${DFS_PLATFORM}

# SYBASE definitions 
if [ -z "$SYBASE" ]; then
  export DFS_SYBASE=/opt/sybase
else
  export DFS_SYBASE=${SYBASE}
fi
export DFS_SYBASE_INCL=${DFS_SYBASE}/include
export DFS_SYBASE_LIB=${DFS_SYBASE}/lib

#
# On Linux RH9.0 there is no valid static libsybdb.a, only
# the shared on works. For other systems use the static one.
#
if [ "$DFS_PLATFORM" = "i586-linux-glibc" ]; then
  export DFS_SYBASE_LIB_VCSOLAC="-L${DFS_SYBASE_LIB} -lsybdb"
else
  export DFS_SYBASE_LIB_VCSOLAC="${DFS_SYBASE_LIB}/libsybdb.a"
fi

# QFITS definitions
export DFS_QFITS=${DFS_EXTERNAL}/qfits
export DFS_QFITS_INCL=${DFS_QFITS}/include
export DFS_QFITS_LIB=${DFS_QFITS}/lib/Linux

# CPPUNIT definitions
export DFS_CPPUNIT=${DFS_EXTERNAL}/cppunit/${DFS_PLATFORM}
export DFS_CPPUNIT_INCL=${DFS_CPPUNIT}/include
export DFS_CPPUNIT_LIB=${DFS_CPPUNIT}/lib

# LOG4CPLUS definitions
export DFS_LOG4CPLUS=${DFS_EXTERNAL}/log4cplus/${DFS_PLATFORM}
export DFS_LOG4CPLUS_INCL=${DFS_LOG4CPLUS}/include
export DFS_LOG4CPLUS_LIB=${DFS_LOG4CPLUS}/lib

# CLASSADS definitions
export DFS_CLASSADS=${DFS_EXTERNAL}/classads/${DFS_PLATFORM}
export DFS_CLASSADS_INCL=${DFS_CLASSADS}/include
export DFS_CLASSADS_LIB=${DFS_CLASSADS}/lib

# SYBCONN definitions
export DFS_SYBCONN=${DFS_EXTERNAL}/sybconn
export DFS_SYBCONN_INCL=${DFS_SYBCONN}/include
export DFS_SYBCONN_LIB=${DFS_SYBCONN}/lib/${DFS_PLATFORM}

# CFITSIO definitions 
export DFS_CFITSIO=${VLTROOT}
export DFS_CFITSIO_INCL=${DFS_CFITSIO}/include
export DFS_CFITSIO_LIB=${DFS_CFITSIO}/lib

# NGAMS CCLIENT definitions
export DFS_NGAMSCCLIENT=${DFS_EXTERNAL}/ngamsCClient
export DFS_NGAMSCCLIENT_INCL=${DFS_NGAMSCCLIENT}/include
export DFS_NGAMSCCLIENT_LIB=${DFS_NGAMSCCLIENT}/lib/${DFS_PLATFORM}


# SOCKET library needed on Solaris
if [ "$DFS_PLATFORM" = "sparc-sun-solaris2.3" ]; then
   export DFS_SOCKET_LIBS="-lnsl -lsocket"
   export DFS_DL_LIB="-ldl"
fi

# NSL (XDR modules) library needed on HP-UX 11.0
if   [ "$DFS_PLATFORM" = "pa_risc-hp-hpux10" ] &&   [ `uname -r` = "B.11.00" ];  then
   export DFS_SOCKET_LIBS="-lnsl"
fi

# VLT documentation script
export DFS_VLT_DOC=${DFS_VLTROOT}/bin/docDoManPages

# X11 include and library needed on Solaris
if [ "$DFS_PLATFORM" = "sparc-sun-solaris2.3" ]; then
   export DFS_X11_INCL="-I/usr/openwin/include"
   export DFS_X11_LIBS="-lX11"
fi  

case "$DFS_PLATFORM" in
  "sparc-sun-solaris2.3")
     export DFS_ASTO_TARGET="ultra_sol_opt"
     export DFS_ASTO_INSTALL_DIR="solaris"
     export PLATFORM=Solaris-GNU-release
     ;;
  "pa_risc-hp-hpux10")
     export DFS_ASTO_TARGET="hppa_hpux_opt"
     export DFS_ASTO_INSTALL_DIR="hpux"
     export PLATFORM=HPUX-GNU-release
     ;;
  "i586-linux-glibc")
     export DFS_ASTO_TARGET="x86_linux"
     export DFS_ASTO_INSTALL_DIR="linux-debug"
     export PLATFORM=Linux-glibc-GNU-release
     ;;
esac   

#
# Add ANT to PATH for OHS packages
#
export PATH=${PATH}:${DFS_EXTERNAL}/ant/bin
