#!/bin/sh 
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# COPYRIGHT (c) 1996 European Southern Observatory
# LICENSE
#
# PROJECT:   VLT Data Flow System
# AUTHOR:    Jeremy Maxfield
# CI NUMBER: 
# DESCRIPTION: Installs boot scripts for dfs system
# REMARKS:     must be run as root 
#              installBoot machine-name
#
# $Id: installBoot.sh,v 1.1 2004/09/06 12:50:28 cguirao Exp $
#
#******************************************************
PATH=/sbin:/usr/sbin:/usr/bin:/bin
export PATH

OS=`uname -s`
ADMIN_DIR=`dirname $0`
SCRIPT_DIR=`dirname $ADMIN_DIR`/boot

case $OS in
  HP-UX)
    BOOT_DIR=/sbin/init.d
    START_DIR=/sbin/rc3.d
    STOP_DIR=/sbin/rc2.d
    ;;
  Linux) 
    exec $ADMIN_DIR/installBootLinux.sh $*
    ;;
  *)
    echo "Unknown OS $OS"
    return 1
    ;;
esac


#
# Copies scripts and creates necessary links
#

function copyToBoot
{
   if [ -f $SCRIPT_DIR/$SCRIPT ]; then
      if [ -f  $BOOT_DIR/$SCRIPT ]; then
         rm -f $BOOT_DIR/$SCRIPT
      fi
      cat $SCRIPT_DIR/$SCRIPT | \
           sed -e "s/XXXXXX/$OWNER/" > $BOOT_DIR/$SCRIPT
      chmod 555   $BOOT_DIR/$SCRIPT
      chown bin:bin $BOOT_DIR/$SCRIPT
      if [ -n "$START_ID" ] ; then
         ln -f -s $BOOT_DIR/$SCRIPT $START_DIR/$START_ID$SCRIPT
      fi
      if [ -n "$STOP_ID" ] ; then
         ln -f -s $BOOT_DIR/$SCRIPT $STOP_DIR/$STOP_ID$SCRIPT
      fi
      return 0
   else
      return 1
   fi
}

function installScript
{
  case $OS in
  HP-UX)
     case $SCRIPT in

     'dfslog')
		START_ID=S220
		STOP_ID=K780
		;;
     'astoDfs')
		START_ID=S220
		STOP_ID=K780
		;;
     'olasDfs')
		START_ID=S220
		STOP_ID=K780
		;;
     'pipelineDfs')
		START_ID=S220
		STOP_ID=K780
		;;
     'qcDfs')
		START_ID=S220
		STOP_ID=K780
		;;
     'qcRawDfs')
		START_ID=S225
		STOP_ID=K775
		;;
     'userOffDfs')
		START_ID=S220
		STOP_ID=K780
		;;
     'vcsolac')
		START_ID=S170
		STOP_ID=K830
		;;
     'ccsLite')
		START_ID=S125
		STOP_ID=K910
		;;
     'msql')
		START_ID=S130
		STOP_ID=K870
		;;
     'pfsmount')
		START_ID=S900
		;;
     *)
		echo "unknown boot script"
		return 1
                 ;;
     esac
     ;;
  esac 
  copyToBoot
  return $?
}

case $1 in
'pfsmount')
	OWNER=root
	SCRIPT=pfsmount
	installScript
	;;
'dfslog')
	OWNER=root
	SCRIPT=dfslog
	installScript
	;;
'msql')
	OWNER=quality
	SCRIPT=msql
	installScript
	;;
'userOffDfs')
	OWNER=mascot
	SCRIPT=userOffDfs
	installScript
	;;
'qcDfs')   
	OWNER=quality
	SCRIPT=qcDfs
	installScript
	;;
'olasDfs')
	OWNER=archeso
	SCRIPT=olasDfs
	installScript
	;;
'pipelineDfs')
	OWNER=pipeline
	SCRIPT=pipelineDfs
	installScript
	;;
'ccsLite')
	OWNER=vlt
	SCRIPT=ccsLite
	installScript
        ;;
'vcsolac')
	if [ -z "$2" ]; then  
          echo "usage: $0 vcsolac <owner> (e.g.: cam,fors,isaac)"
	  exit 1;
	fi
	OWNER=$2
	SCRIPT=vcsolac
	installScript
	;;
*)
	echo "usage: $0 machine-name|script"
	;;
esac
