#!/bin/sh
#
#   Copyright (C) 1994-1998 TakeFive Software Software GmbH.
#
# Author: Gerhard Scheutz <kerm@takeFive.co.at>
# Maintainer: Gerhard Scheutz <kerm@takeFive.co.at>
# Created: 09 Nov 1994
# Keywords: tools sniff
#
# Commentary:
#
# This script attempts to guess system architecture for sniff
#
# Acknowledgements:
#
# Thanks to Per Bothner <bothner@cygnus.com> for some ideas
#
# Code:

set LANG=
 
# /dev/null support
devnull="/dev/null"
alternativedevnull="/nul"
# note that since /dev/null is not a 'regular' file, -f test can't be
# used
if [ ! -w "$devnull" ]
then
	devnull="$alternativedevnull"
	# don't try to check for alternativedevnull...
fi
 
UNAME_MACHINE=`(uname -m) 2>$devnull` || UNAME_MACHINE=unknown
UNAME_RELEASE=`(uname -r) 2>$devnull` || UNAME_RELEASE=unknown
UNAME_SYSTEM=`(uname -s) 2>$devnull` || UNAME_SYSTEM=unknown
UNAME_VERSION=`(uname -v) 2>$devnull` || UNAME_VERSION=unknown

case "${UNAME_MACHINE}:${UNAME_SYSTEM}:${UNAME_RELEASE}:${UNAME_VERSION}" in
	alpha:OSF1:V1*:*)
		echo alpha-dec-osf1.0
		exit 0 ;;
    alpha:OSF1:V2*:*)
		# After 1.2, OSF1 uses "V1.3" for uname -r.
		echo alpha-dec-osf2.0
		exit 0 ;;
    alpha:OSF1:V[34]*:*)
        echo alpha-dec-osf3.0
        exit 0 ;;
    sun4*:SunOS:5.*:*)
		echo sparc-sun-solaris2.3
		exit 0 ;;
    sun4*:SunOS:4.1*:*)
		# only the fist 3 digits are used
		echo sparc-sun-sunos`echo ${UNAME_RELEASE}|cut -c 1-3`
		exit 0 ;;
    RISC*:ULTRIX:4.[34]:*)
		echo mips-dec-ultrix4.3
		exit 0 ;;
    RISC*:ULTRIX:*:*)
		echo mips-dec-ultrix${UNAME_RELEASE}
		exit 0 ;;
    *:IRIX*:*:*)
		echo mips-sgi-irix5.3
		exit 0 ;;
    *:AIX*:[21]:[3])
		echo rs6000-ibm-aix3.2
		exit 0 ;;
	*:AIX:[123]:[45])
		echo rs6000-ibm-aix4.2
		exit 0 ;;		
    9000/[3478]??:HP-UX:*:*)
	case "${UNAME_MACHINE}" in
	    9000/31? )            HP_ARCH=m68000 ;;
	    9000/[34]?? )         HP_ARCH=m68k ;;
	    9000/7?? | 9000/8?7 ) HP_ARCH=pa_risc;;
	    9000/8?? )            HP_ARCH=pa_risc ;;
	esac
	REV=`echo ${UNAME_RELEASE}|sed -e 's/[^.]*.[0B]*//'`
	# HPUX_REV=`printf "%1.0f" $REV`
	HPUX_REV=`echo $REV| cut -d. -f1`
	if [ "$HPUX_REV" = "9" ]
	  then
		echo ${HP_ARCH}-hp-hpux9.0
	  else
		echo ${HP_ARCH}-hp-hpux10
	fi
	exit 0 ;;
#On FreeBSD, use linux compatibility mode
#Same for BSD/OS
    *:FreeBSD:*:*)
        echo i586-linux-glibc
        exit 0 ;;
    *:BSD/OS:*:*)
        echo i586-linux-glibc
        exit 0 ;;
    *:Linux:*:*)
		if [ -r "/usr/include/features.h" ]; then
			GLIBC_VERSION=`awk '/#define.*__GLIBC__/ {print $3}' /usr/include/features.h`
			GLIBC_MINOR_VERSION=`awk '/#define.*__GLIBC_MINOR__/ {print $3}' /usr/include/features.h`
			if [ "$GLIBC_VERSION" != "" -a "$GLIBC_MINOR_VERSION" != "0" ]; then
				echo i586-linux-glibc
				exit 0
			fi
		fi
		;;
	i[34]86:*:3.2:*)
		echo i386-unknown-sco3.2v4.2
		exit 0 ;;
    i86pc:SunOS:5.*:*)
        echo i386-unknown-solaris2.4
        exit 0 ;;
	i[34]86:UNIX_SV:4.2MP:*)
		echo i386-unknown-sysv${UNAME_RELEASE}
		exit 0 ;;
	i[34]86:UnixWare:*:*)
		echo i386-unknown-unixware7
		exit 0 ;;
	3[245]??:UNIX_SV:4.0:*)
		echo i386-ncr-sysv${UNAME_RELEASE}
		exit 0 ;;
	3[245]??/3[245]??:UNIX_SV:4.0:*)
		echo i386-ncr-sysv${UNAME_RELEASE}
		exit 0 ;;
	3[2345]??,3[2345]??*:[nN][cC][rR]*:4.0:*)
		echo i386-ncr-sysv${UNAME_RELEASE}
		exit 0 ;;
	*:SINIX-*:*:* | *:ReliantUNIX-*:*:*)
		echo mips-sni-sinix5.42
		exit 0 ;;
	*86:CYGWIN_NT*:*:*)
		echo "i386-unknown-winnt4"
		exit 0
		;;
	*86:CYGWIN_9[58]*:*:*)
		echo "i386-unknown-win95"
		exit 0
		;;
	*86:WindowsNT*:*:*)
		echo "i386-unknown-winnt4"
		exit 0
		;;
	*86:Windows[58]*:*:*)
		echo "i386-unknown-win95"
		exit 0
		;;
esac

echo "SNiFF+ unsupported system type" 1>&2
echo "MACHINE=$UNAME_MACHINE" 1>&2
echo "RELEASE=$UNAME_RELEASE" 1>&2
echo "SYSTEM=$UNAME_SYSTEM" 1>&2
echo "VERSION=$UNAME_VERSION" 1>&2

exit 1
