#******************************************************************************
# E.S.O. - VLT project
#
# "@(#) Id: ESO-VLT-DIC.ASM,v 5.13 2004/01/26 00:08:16 vltsccm Exp $"
#
# who       when      what
# --------  --------  ----------------------------------------------
# mkiekebu 2004-01-25 changed format of Version Control keyword 
# jargomed 2002-05-08 added seqouts TAU0, NL, TS, RFLRMS and TETHA0
# ssandroc  30/06/99  SPR 990251: replaced all formats %g -> %f
# ssandroc  13/03/99  GEN.AMBI.SITE added.
# ssandroc  22/11/98  0.5: SKYBG indexed, added CCDTEMP.
# ssandroc  10/11/98  0.4: updated comment and description fields
# ssandroc  08/07/98  0.3: added ops-log keywords
# ssandroc  03/07/98  0.2: RA and DEC format changed
# ssandroc  01/07/98  0.1: submitted
# ssandroc  06/06/98  created
#

#************************************************************************
#   NAME
#	ESO-VLT-DIC.ASM - Data Interface Dictionary for ASM
#
#   DESCRIPTION
#	Dictionary for all data items delivered by the VLT ASM
#	and internal parameters.
#
#	The dictionary is divided into public data parameters, which all
#	fall into the GEN AMBI cathegory, and operational logs with
#	TEL and INS main keywords that record internal ASM parameters.
#
#   EVENT SOURCE MASKS
#	The event source mask for generated ops-logs can have the value:
#	wasm	ASM workstation
#	lasm1	ASM telescope and external sensor units LCU
#	lasm2	ASM DIMM CCD LCU (alternatively "DIMM" is used)
#
#   SEE ALSO
#
#------------------------------------------------------------------------

Dictionary Name:   ESO-VLT-DIC.ASM
Scope:             Astronomical Site Monitor
Source:            ssandroc@eso.org
Version Control:   @(#) $Id: ESO-VLT-DIC.ASM,v 1.1 2004/09/06 14:31:40 cguirao Exp $
Description:       Dictionary for the VLT Astronomical Site Monitor

#--------------------------------------------------------------------------
#
# ASM provided public parameters (GEN AMBI)
#
#--------------------------------------------------------------------------

Parameter Name:    GEN AMBI SITE
Class:             cond-log
Context:           General
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Site name for origin of ambient data sample
Description:       This is the site where the data comes from.
                   It can be PARANAL or LASILLA.

Parameter Name:    GEN AMBI DATE
Class:             cond-log
Context:           General
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Date and time of ambient data sample
Description:       This is the time when this ambient data set has
		   been delivered.

Parameter Name:    GEN AMBI INTERVAL
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.f
Unit:              s
Comment Field:     Timespan used for measurement of ambient data sample
Description:       This is the time-span needed to measure this ambient
		   data set prior to the time of its delivery.


Parameter Name:    GEN AMBI FWHM
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              arcsec
Comment Field:     Observatory Seeing for 500 nm wavelength at zenith
Description:       Site seeing as measured by the ASM-DIMM telescope in
		   6 m height, full width half maximum at 500 nm wavelength.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI DIMM AIRMASS
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.1f
Unit:              
Comment Field:     Airmass for measured observatory seeing
Description:       Airmass at which the ASM-DIMM telescope measured
		   the site seeing.

Parameter Name:    GEN AMBI DIMM RA
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %HOURANG: RA for measured observatory seeing
Description:       Right ascension at which the ASM-DIMM telescope measured
		   the site seeing.

Parameter Name:    GEN AMBI DIMM DEC
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %DEGREE: Dec for measured observatory seeing
Description:       Declination at which the ASM-DIMM telescope measured
		   the site seeing.



Parameter Name:    GEN AMBI TEMPi
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              C
Comment Field:     Observatory ambient temperature @ 30/2/-0.1 m
Description:       Temporal mean of site ambient temperature measured 
		   at sensor position i = 1/2/3 in 30m/2m/-0.1m height,
		   where -0.1m means ground temperature.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI TEMPDEWi
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              C
Comment Field:     Observatory ambient dew temperature @ 30/2 m
Description:       Temporal mean of site ambient dew temperature 
		   measured at sensor position i = 1/2 in 30m/2m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI RHUMi
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.f
Unit:              percent
Comment Field:     Observatory ambient relative humidity @ 30/2 m
Description:       Temporal mean of site ambient relative humidity 
		   measured at sensor position i = 1/2 in 30m/2m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI PRES
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              hPa
Comment Field:     Observatory ambient air pressure
Description:       Temporal mean of site barometric air pressure measured
		   with sensor at ground level.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI PRESQNH
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              hPa
Comment Field:     Observatory ambient air pressure normalized to see level
Description:       Temporal mean of site air pressure normalized to see level.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI WIND DIRi
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.f
Unit:              deg
Comment Field:     Observatory ambient wind direction @ 30/10/20 m (N=0 E=90)
Description:       Temporal mean of site ambient wind direction 
		   measured at sensor position i = 1/2 in 30m/10m height.
		   For La Silla there is also i = 3 for 20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI WIND SPEEDi
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              m/s
Comment Field:     Observatory ambient wind speed @ 30/10/20 m
Description:       Temporal mean of site ambient wind speed measured 
		   at sensor position i = 1/2 in 30m/10m height.
		   For La Silla there is also i = 3 for 20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI WIND SPEEDU
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              m/s
Comment Field:     Observatory ambient wind speed 3-D component U @ 20 m
Description:       Temporal mean of site ambient wind speed U vector component,
		   where U is horizontal and points to 330 degree (approx. NNW),
		   measured at sensor position in 20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI WIND SPEEDV
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              m/s
Comment Field:     Observatory ambient wind speed 3-D component V @ 20 m
Description:       Temporal mean of site ambient wind speed V vector component,
		   where V is horizontal and points to 240 degree (approx. WSW),
		   measured at sensor position in 20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI WIND SPEEDW
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              m/s
Comment Field:     Observatory ambient wind speed 3-D component W @ 20 m
Description:       Temporal mean of site ambient wind speed W vector component,
		   where W is vertically pointing upwards,
		   measured at sensor position in 20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI DUSTSi
Class:             cond-log
Context:           General
Type:              integer
Value Format:      %d
Unit:              1/m^3
Comment Field:     Observatory ambient 0.5 um dust particle count @ 30/20 m
Description:       Temporal mean of site ambient dust particle count
		   of 0.5 um size per cubic-meter,
		   measured at sensor position i = 1/2 in 30m/20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI DUSTLi
Class:             cond-log
Context:           General
Type:              integer
Value Format:      %d
Unit:              1/m^3
Comment Field:     Observatory ambient 5 um dust particle count @ 30/20 m
Description:       Temporal mean of site ambient dust particle count
		   of 5 um size per cubic-meter,
		   measured at sensor position i = 1/2 in 30m/20m height.
		   This parameter is delivered by the ASM at intervals
                   of typically 1 minute.

Parameter Name:    GEN AMBI TAU
Class:             cond-log
Context:           General
Type:              double
Value Format:      %f
Unit:              s
Comment Field:     Wavefront Coherence Time (s, 1mn average)
Description:       Wavefront Coherence Time (ms, 1mn average) as derived
		   from DIMM Seeing measurements and Atmospheric Wind Profiles 
		   ECMWF forecasts

Parameter Name:    GEN AMBI RFL 
Class:             cond-log
Context:           General
Type:              double
Value Format:      %f
Unit:              ratio
Comment Field:     Relative Flux RMS variations (10mn exposure)
Description:       Relative Flux RMS variations (10mn exposure) as
		   measured by DIMM along the Line of sight

Parameter Name:    GEN AMBI TET
Class:             cond-log
Context:           General
Type:              double
Value Format:      %.2f
Unit:              arcsec
Comment Field:     Wavefront Isoplanatic Angle (arcsec, 10mn average)
Description:       Wavefront Isoplanatic Angle (arcsec, 10mn average) as
		   derived from DIMM Scintillation measurements corrected from exposure
		   time averaging by ECMWF jet stream velocity forecasts

#--------------------------------------------------------------------------
#
# ASM internal parameters for ops-log
#
#--------------------------------------------------------------------------

#
# ASM Target Stars
#

Parameter Name:    TEL CAT START
Class:             ops-log
Context:           Telescope|Catalog
Type:              string
Value Format:      %s
Unit:
Comment Field:     Selecting new target star
Description:       This action is logged at the beginning of new target star selection.

Parameter Name:    TEL CAT HALFSKY
Class:             ops-log
Context:           Telescope|Catalog
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Half-sky selection (North/South/Both)
Description:       This value is logged when new target star is going to be selected (asmcat).

Parameter Name:    TEL CAT PRIOHA
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              deg
Comment Field:     Selection priority of hour angle
Description:       This value is logged when new target star is going to be selected (asmcat).

Parameter Name:    TEL CAT PRIOMAG
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              deg
Comment Field:     Selection priority of magnitude
Description:       This value is logged when new target star is going to be selected (asmcat).

Parameter Name:    TEL CAT HAREF
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              h
Comment Field:     Preferred hour angle
Description:       This value is logged when new target star is going to be selected (asmcat).
#                  Note: value in decimal hours!

Parameter Name:    TEL CAT MAXHA
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              h
Comment Field:     Maximum tracking hour angle
Description:       This value is logged when new target star is going to be selected (asmcat).
#                  Note: value in decimal hours!

Parameter Name:    TEL CAT MAXAIRM
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              
Comment Field:     Maximum starting airmass
Description:       This value is logged when new target star is going to be selected (asmcat).

Parameter Name:    TEL CAT MAXMAG
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              
Comment Field:     Maximum magnitude 
Description:       This value is logged when new target star is going to be selected (asmcat).

Parameter Name:    TEL CAT TWILIGHT
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %f
Unit:              deg
Comment Field:     Twilight definition
Description:       This value is logged when new target star is going to be selected (asmcat).

# Note: the calculated selection criteria during the selection process
# of all stars in the catalog could additionally be logged as COMMENT.

Parameter Name:    TEL CAT AUTO
Class:             ops-log
Context:           Telescope|Catalog
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Auto-selected target star
Description:       This value is logged when a target star is automatically selected,
                   with name, esitmated tracking duration and selection criteria.

Parameter Name:    TEL CAT FIX
Class:             ops-log
Context:           Telescope|Catalog
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Fixed target star
Description:       This value is logged when a target star is manually selected.
#                  Note: this should for consistency be enclosed in CAT STOP and CAT START.

Parameter Name:    TEL CAT TIME
Class:             ops-log
Context:           Telescope|Catalog
Type:              double
Value Format:      %.0f
Unit:              s
Comment Field:     Tracking duration of selected target star
Description:       This value is logged when new target star is selected.

Parameter Name:    TEL CAT STOP
Class:             ops-log
Context:           Telescope|Catalog
Type:              string
Value Format:      %s
Unit:
Comment Field:     Abandoning target star
Description:       This action is logged when the target star is dropped for a new one.


#
# ASM Telescope
#

# - TEL INIT

Parameter Name:    TEL INIT START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Initializing telescope
Description:       This action is logged when the telescope starts to be initialized.

Parameter Name:    TEL INIT STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Telescope is initialized
Description:       This action is logged when the telescope is completely initialized.

# - TEL ETA

Parameter Name:    TEL ETA SIDE
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Telescope ETA axis operating half-sky
Description:       This action is logged when the telescope eta axis is initialized (asmtel).

Parameter Name:    TEL ETA AMPL START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enable ETA drive amplifier
Description:       This action is logged when the telescope eta drive amplifier is switched on (asmtel).

Parameter Name:    TEL ETA AMPL STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Disable ETA drive amplifier
Description:       This action is logged when the telescope eta drive amplifier is switched off (asmtel).

Parameter Name:    TEL ETA INIT START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Initializing telescope ETA axis
Description:       This action is logged when the telescope eta axis starts to be initialized (asmtel).

Parameter Name:    TEL ETA INIT STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Telescope ETA axis is initialized
Description:       This action is logged when the telescope eta axis is initialized (asmtel).

# - TEL THETA

Parameter Name:    TEL THETA SIDE
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Telescope THETA axis operating half-sky
Description:       This action is logged when the telescope theta axis is initialized (asmtel).

Parameter Name:    TEL THETA AMPL START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enable THETA drive amplifier
Description:       This action is logged when the telescope theta drive amplifier is switched on (asmtel).

Parameter Name:    TEL THETA AMPL STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Disable THETA drive amplifier
Description:       This action is logged when the telescope theta drive amplifier is switched off (asmtel).

Parameter Name:    TEL THETA INIT START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Initializing telescope THETA axis
Description:       This action is logged when the telescope theta axis starts to be initialized (asmtel).

Parameter Name:    TEL THETA INIT STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Telescope THETA axis is initialized
Description:       This action is logged when the telescope theta axis is initialized (asmtel).

# - TEL PRESET

Parameter Name:    TEL PRESET START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Presetting telescope to new position
Description:       This action is logged when presetting to a new target star (asmws).

Parameter Name:    TEL PRESET NAME
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:              
Comment Field:     Name of the target star
Description:       This action is logged when presetting to a new target star (asmws).
#                  Note: compare also TEL CAT AUTO/FIX.

Parameter Name:    TEL PRESET RA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %HOURANG: nominal telescope preset position RA J2000
Description:       This position is logged only on change due to a new preset (asmws).
#                  Note: value in decimal degrees!

Parameter Name:    TEL PRESET DEC
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %DEGREE: nominal telescope preset position DEC J2000
Description:       This position is logged only on change due to a new preset (asmws).
#                  Note: value in decimal degrees!

Parameter Name:    TEL PRESET POINTSOL
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Pointing solution values
Description:       The currently applied pointing model terms.
                   These values are logged only on change due to a new preset (asmws).
#                  Note: this is the string returned by asmtrkServer/GETTERM command.

Parameter Name:    TEL PRESET STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Presetting telescope completed
Description:       This action is logged when presetting is completed (asmws).
#                  Note: normally identical to TRACK START

# - TEL TRACK

Parameter Name:    TEL TRACK START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Telescope tracking target star
Description:       This action is logged when the telescope state changes from PRESETTING to TRACKING (asmws).

Parameter Name:    TEL TRACK STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Telescope tracking stopped
Description:       This action is logged when the telescope state changes from TRACKING to something else not caused by a new preset (asmws).

# - TEL CENTER

Parameter Name:    TEL CENTER START
Class:             ops-log
Context:           Telescope|Autoguider
Type:              string
Value Format:      %s
Unit:
Comment Field:     Centering target star
Description:       This action is logged at beginning of the centering procedure (asmws).

Parameter Name:    TEL CENTER WAIT
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.0f
Unit:              s
Comment Field:     Waiting time before starting iteration counter
Description:       This value s logged at the beginning of the centering procedure (asmws).

Parameter Name:    TEL CENTER MAXITER
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.0f
Unit:
Comment Field:     Maximum number of centering iterations
Description:       This value s logged at the beginning of the centering procedure (asmws).

Parameter Name:    TEL CENTER ITER
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.0f
Unit:
Comment Field:     Total number of centering iterations
Description:       This value s logged at the end of the centering procedure (asmws).

Parameter Name:    TEL CENTER TIME
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.0f
Unit:              s
Comment Field:     Total time needed for centering procedure
Description:       This value s logged at the end of the centering procedure (asmws).

Parameter Name:    TEL CENTER STOP
Class:             ops-log
Context:           Telescope|Autoguider
Type:              string
Value Format:      %s
Unit:
Comment Field:     Target star is centered
Description:       This action is logged when the target star centered (asmws).

# - TEL SNOOPY

Parameter Name:    TEL SNOOPY START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Snoopy sent out to search for target star outside the field
Description:       This action is logged during the centering procedure
                   once the target star is not found in the field
                   and a searching procedure outside the field is started (asmws).

Parameter Name:    TEL SNOOPY STEPX
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Snoopy horizontal field step size
Description:       This value is logged when Snoopy is started (asmws).

Parameter Name:    TEL SNOOPY STEPY
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Snoopy vertical field step size
Description:       This value is logged when Snoopy is started (asmws).

Parameter Name:    TEL SNOOPY THRESHLD
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.0f
Unit:              
Comment Field:     Number of iterations before starting searching
Description:       This value is logged when Snoopy is started (asmws).

Parameter Name:    TEL SNOOPY POSX
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.0f
Unit:
Comment Field:     Snoopy horizontal field position
Description:       This value is logged each time the searching procedure
                   proceeds to the next raster field (asmws).

Parameter Name:    TEL SNOOPY POSY
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.0f
Unit:
Comment Field:     Snoopy vertical field position
Description:       This value is logged each time the searching procedure
                   proceeds to the next raster field (asmws).

Parameter Name:    TEL SNOOPY STOP
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Snoopy sent to sleep
Description:       This action is logged during the centering procedure
                   when the target star first comes into the field
                   after the searching procedure outside the field (asmws).

# - TEL POS

Parameter Name:    TEL POS RA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %HOURANG: actual telescope position RA J2000 from backward calculation
Description:       This position is logged at regular intervals.
#                  Note: requires that Autopommer is running and it puts the result into the DB.

Parameter Name:    TEL POS DEC
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.6f
Unit:              deg
Comment Field:     %HOURANG: actual telescope position DEC J2000 from backward calculation
Description:       This position is logged at regular intervals.
#                  Note: requires that Autopommer is running and it puts the result into the DB.

Parameter Name:    TEL POS ETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %f
Unit:              deg
Comment Field:     actual telescope position in ETA N/S
Description:       This position is logged at intervals of typically 1 minute.

Parameter Name:    TEL POS THETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %f
Unit:              deg
Comment Field:     actual telescope position in THETA E/W
Description:       This position is logged at intervals of typically 1 minute.

# - TEL OFFSET - explicit offset

Parameter Name:    TEL OFFSET START
Class:             ops-log
Context:           Telescope
Type:              string
Value Format:      %s
Unit:
Comment Field:     Initiate new telescope offset
Description:       This action is logged when an offset is made. 
                   Note that NO action is logged when the offset ends.

Parameter Name:    TEL OFFSET RA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Offset applied in RA
Description:       The offset applied to the telescope in RA.

Parameter Name:    TEL OFFSET DEC
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Offset applied in DEC
Description:       The offset applied to the telescope in DEC.

Parameter Name:    TEL OFFSET ETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Offset applied in ETA N/S
Description:       The offset applied to the telescope in ETA N/S.

Parameter Name:    TEL OFFSET THETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Offset applied in THETA E/W
Description:       The offset applied to the telescope in THETA E/W.

Parameter Name:    TEL OFFSET ACCETA
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Total accumulated offset applied in ETA N/S
Description:       The accumulated total offset applied to the telescope in ETA N/S
                   This value is logged at regular intervals.

Parameter Name:    TEL OFFSET ACCTHETA
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Total accumulated offset applied in THETA E/W
Description:       The accumulated total offset applied to the telescope in THETA E/W
                   This value is logged at regular intervals.

# - TEL POFF - effective pointing offset

Parameter Name:    TEL POFF ETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Effective pointing offset after centering in ETA N/S
Description:       The pointing offset applied to the telescope in ETA N/S for centering.
                   It is the position difference before and after the centering procedure.
                   This value is logged after every centering correction.

Parameter Name:    TEL POFF THETA
Class:             ops-log
Context:           Telescope
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Effective pointing offset after centering in THETA E/W
Description:       The pointing offset applied to the telescope in THETA E/W for centering.
                   It is the position difference before and after the centering procedure.
                   This value is logged after every centering correction.

# - TEL AG

Parameter Name:    TEL AG START
Class:             ops-log
Context:           Telescope|Autoguider
Type:              string
Value Format:      %s
Unit:
Comment Field:     Autoguider started
Description:       This action is logged when the autoguider function is enabled.

Parameter Name:    TEL AG STOP
Class:             ops-log
Context:           Telescope|Autoguider
Type:              string
Value Format:      %s
Unit:
Comment Field:     Autoguider stopped
Description:       This action is logged when the autoguider function is disabled.

Parameter Name:    TEL AG ETA
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Error vector in ETA (N/S)
Description:       Autoguiding correction sent to the telescope in ETA (N/S)
                   This value is logged for every auto-guiding correction, but not for centering.
#                  Note: we won't do that by default - too verbose!

Parameter Name:    TEL AG THETA
Class:             ops-log
Context:           Telescope|Autoguider
Type:              double
Value Format:      %.3f
Unit:              arcsec
Comment Field:     Error vector in THETA (E/W)
Description:       Autoguiding correction sent to the telescope in THETA (E/W)
                   This value is logged for every auto-guiding correction, but not for centering.
#                  Note: we won't do that by default - too verbose!


#
# ASM Enclosure
#

Parameter Name:    TEL ENCL OPEN START
Class:             ops-log
Context:           Telescope|Enclosure
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enclosure starts to open
Description:       This action is logged when the enclosure starts to open (asmten).

Parameter Name:    TEL ENCL OPEN STOP
Class:             ops-log
Context:           Telescope|Enclosure
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enclosure is opened
Description:       This action is logged when the enclosure is finally opened (asmten).

Parameter Name:    TEL ENCL CLOSE START
Class:             ops-log
Context:           Telescope|Enclosure
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enclosure starts to close
Description:       This action is logged when the enclosure starts to close (asmten).

Parameter Name:    TEL ENCL CLOSE STOP
Class:             ops-log
Context:           Telescope|Enclosure
Type:              string
Value Format:      %s
Unit:
Comment Field:     Enclosure is closed
Description:       This action is logged when the enclosure is finally closed (asmten).

Parameter Name:    TEL ENCL NORTH POS
Class:             ops-log
Context:           Telescope|Enclosure
Type:              double
Value Format:      %.0f
Unit:              deg
Comment Field:     Enclosure north-half position
Description:       This value is logged at regular intervals during movement (asmten).
#                  Note: TBC if this is reasonable!

Parameter Name:    TEL ENCL SOUTH POS
Class:             ops-log
Context:           Telescope|Enclosure
Type:              double
Value Format:      %.0f
Unit:              deg
Comment Field:     Enclosure south-half position
Description:       This value is logged at regular intervals during movement (asmten).
#                  Note: TBC if this is reasonable!

# Note: events triggered to daylight sensor or manual switch shall be logged as UNFORSEEN.


#
# ASM Meteo
#

Parameter Name:    INS METEO START
Class:             ops-log
Context:           Instrument
Type:              string
Value Format:      %s
Unit:
Comment Field:     Start recording of meteorological data
Description:       This action is logged when the interface to Meteo is started (asmmet).

Parameter Name:    INS METEO STOP
Class:             ops-log
Context:           Instrument
Type:              string
Value Format:      %s
Unit:
Comment Field:     Stop recording of meteorological data
Description:       This action is logged when the interface to Meteo is stopped (asmmet).

# Note: any communication error and badly formatted frame shall be logged as UNFORSEEN/RECOVERY.
# Note: no meteo data values are logged since everything is going into the PAFs anyway.


#
# DIMM General
#


#
# DIMM Hardware Constants
#

Parameter Name: INS DIMM CONST PHI
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Telescope Diameter
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST FR
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           
Comment Field:  Telescope F Ratio
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST FL
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Objective Focal Length
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PA
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           deg
Comment Field:  Pupil Mask Prism Angle
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST MD
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Mask Hole Diameter
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST MS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Mask Hole Separation
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PD
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Pupils Diameter
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Pupils Separation
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST CCDX
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           pixel
Comment Field:  X CCD total size
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST CCDY
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           pixel
Comment Field:  Y CCD total size
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST AF
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           
Comment Field:  CCD noise floor (explicit ad-count if >0, implicit n-sigma if <0)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PSX
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  X Pixel Size
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PSY
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Y Pixel Size
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PPX
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           arcsec
Comment Field:  X Pixel Angular Pitch
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST PPY
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           arcsec
Comment Field:  Y Pixel Angular Pitch
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST W0
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           pixel
Comment Field:  Spot separation (nominal)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST INX
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           pixel^2
Comment Field:  X Instrumental Noise (measured)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST INY
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           pixel^2
Comment Field:  Y Instrumental Noise (measured)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM CONST LAMBDA
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           m
Comment Field:  Wavelength
Description:    This value is logged once at startup and on any change.


#
# DIMM Autoguider
#

Parameter Name: INS DIMM AG START
Class:          ops-log
Context:        Instrument|Autoguider
Type:           string
Value Format:   %s
Unit:           
Comment Field:  Initiating setup to center target star
Description:    This action is logged at start of centering (asmdim).

Parameter Name: INS DIMM AG STOP
Class:          ops-log
Context:        Instrument|Autoguider
Type:           string
Value Format:   %s
Unit:           
Comment Field:  Star is inside target radius
Description:    This action is logged at end of centering (asmdim).

Parameter Name:    INS DIMM AG LOCKED
Class:             ops-log
Context:           Instrument|Autoguider
Type:              string
Value Format:      %s
Unit:
Comment Field:     Locked on target
Description:       This action is logged when the target star first enters the field (asmdim).

Parameter Name:    INS DIMM AG ENABLE
Class:             ops-log
Context:           Instrument|Autoguider
Type:              logical
Value Format:      %c
Unit:              
Comment Field:     Autoguider enable status
Description:       This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG REFX
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:              pixel
Comment Field:     Autoguider reference pixel X
Description:       Autoguider TCCD reference pixel for centroiding.
                   This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG REFY
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:              pixel
Comment Field:     Autoguider reference pixel Y
Description:       Autoguider TCCD reference pixel for centroiding.
                   This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG DIT
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:              s
Comment Field:     Autoguider base exposure time
Description:       This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG RADIUS
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:              arcsec
Comment Field:     Autoguider in-target radius
Description:       Autoguider in-target radius for centering.
                   This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG RATE
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %.0f
Unit:
Comment Field:     Autoguider update rate
Description:       Autoguider update rate for averaging exposures.
                   This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG KPX
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:
Comment Field:     Autoguider proportional gain X
Description:       This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG KPY
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:
Comment Field:     Autoguider proportional gain Y
Description:       This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG KIX
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:
Comment Field:     Autoguider integral gain X
Description:       This value is logged once at startup and on any change.

Parameter Name:    INS DIMM AG KIY
Class:             ops-log
Context:           Instrument|Autoguider
Type:              double
Value Format:      %f
Unit:
Comment Field:     Autoguider integral gain Y
Description:       This value is logged once at startup and on any change.


#
# DIMM Mode Setup
#

Parameter Name: INS DIMM MODE NAME
Class:          ops-log
Context:        Instrument
Type:           string
Value Format:   %s
Unit:           
Comment Field:  Executing mode name (DIMM or WFCE)
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM MODE TD
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           s
Comment Field:  Exposure time
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM MODE ND
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Exposures per frame
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM MODE N
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Frames per sequence
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM MODE NX
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           pixel
Comment Field:  X CCD sub-array size
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM MODE NY
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           pixel
Comment Field:  Y CCD sub-array size
Description:    This value is logged at the beginning of each sequence.


#
# DIMM Validation Limits
#

Parameter Name: INS DIMM LIMIT KR
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Saturation Limit (ad count)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KP
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Valid Pixels Limit
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT SNMIN
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  S/N Ratio Limit
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KE
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           percent
Comment Field:  Spot Elongation Limit
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KF
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Spot Decentering Limit (times of FWHM)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KC
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Gaussian Clipping Limit (rms of distribution)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KN1
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           percent
Comment Field:  Rejected Exposures Limit
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KN2
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           percent
Comment Field:  Clipped Exposures Limit
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Statistical Error Limit 1/sqrt(N-1)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KO
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Polynomial order for error-curve fitting (0=off)
Description:    This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KS1
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Max number of consecutive rejected sequences for a star (0=off)
Description:    If the number is reached then a change of star is requested.
                This value is logged once at startup and on any change.

Parameter Name: INS DIMM LIMIT KS2
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Max total number of rejected sequences for a star (0=off)
Description:    If the number is reached then a change of star is requested.
                This value is logged once at startup and on any change.


#
# DIMM Sequence Actions
#

Parameter Name: INS DIMM SEQ START
Class:          ops-log
Context:        Instrument
Type:           string
Value Format:   %s
Unit:           
Comment Field:  Seeing measurement sequence started
Description:    This action is logged when a measurement sequence is started.

Parameter Name: INS DIMM SEQ STOP
Class:          ops-log
Context:        Instrument
Type:           string
Value Format:   %s
Unit:           
Comment Field:  Seeing measurement sequence completed
Description:    This action is logged when a measurement sequence is completed.
# Note: invalidated sequences shall be logged with Comment before INS DIMM SEQ STOP.


#
# DIMM Sequence Input Parameters
#

Parameter Name: INS DIMM SEQIN RA
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           deg
Comment Field:  %HOURANG: position in RA of target star
Description:    This value is logged at the beginning of each sequence.
#               Note: value in decimal degrees!

Parameter Name: INS DIMM SEQIN DEC
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           deg
Comment Field:  %DEGREE: position in DEC of target star
Description:    This value is logged at the beginning of each sequence.
#               Note: value in decimal degrees!

Parameter Name: INS DIMM SEQIN MAG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           mag
Comment Field:  Magnitude of target star
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM SEQIN ZD
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           deg
Comment Field:  Zenith distance of target star
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM SEQIN AIRMASS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           
Comment Field:  Airmass of target star
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM SEQIN SKYBG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Sky background input
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM SEQIN N
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Number of requested exposures for sequence
Description:    This value is logged at the beginning of each sequence.

Parameter Name: INS DIMM SEQIN CCDTEMP
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           
Comment Field:  CCD chip temperature before sequence
Description:    This value is logged at the beginning of each sequence.

#
# DIMM Sequence Output Parameters
#

Parameter Name: INS DIMM SEQOUT CCDTEMP
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.2f
Unit:           
Comment Field:  CCD chip temperature after sequence
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT NVAL
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Number of validated exposures for sequence
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT DN1
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Number of exposures rejected in the frame validation
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT DN2
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Number of exposures rejected in the statistical validation
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT XG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           pixel
Comment Field:  Image cdg X (measured)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT YG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           pixel
Comment Field:  Image cdg Y (measured)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT WG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           pixel
Comment Field:  Spot Separation (measured)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT ALPHAG
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           deg
Comment Field:  Spot Axis Rotation vs CCD-x (measured)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT DIT
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           s
Comment Field:  Average Exposure Time (measured)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT DITVAR
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           s^2
Comment Field:  Variance on Exposure Time
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT SNR
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Signal-to-Noise ratio
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT SKYBGi
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           
Comment Field:  Sky background of window 1/2
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT SKYBGVAR
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           
Comment Field:  Variance on Sky background
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FLUXi
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Flux of window 1/2
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FXi
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           pixel
Comment Field:  Average FWHM(y) of spot 1/2
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FYi
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           pixel
Comment Field:  Average FWHM(y) of spot 1/2
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT Si
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           percent
Comment Field:  Scintillation Index of spot 1/2
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT SI
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           percent
Comment Field:  Scintillation Index avg.
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT VARPARAN
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec^2
Comment Field:  Variance of differential motion parallel (without fitting)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT VARPERPN
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec^2
Comment Field:  Variance of differential motion perpendicular (without fitting)
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT VARPARA
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec^2
Comment Field:  Variance of differential motion parallel
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT VARPERP
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec^2
Comment Field:  Variance of differential motion perpendicular
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FWHMPARA
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec
Comment Field:  Seeing parallel
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FWHMPERP
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec
Comment Field:  Seeing perpendicular
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT FWHM
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec
Comment Field:  Seeing average
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT TAU0
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           s
Comment Field:  Average coherence time
Description:    This value is logged at the end of each sequence.

#
# Equivalent long exposure results
#

Parameter Name: INS DIMM SEQOUT NL
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %.0f
Unit:           
Comment Field:  Long exposure validated exposures
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT TS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %e
Unit:           s
Comment Field:  Long exposure time
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT RFLRMS
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           ratio
Comment Field:  Relative rms flux variation
Description:    This value is logged at the end of each sequence.

Parameter Name: INS DIMM SEQOUT THETA0
Class:          ops-log
Context:        Instrument
Type:           double
Value Format:   %f
Unit:           arcsec
Comment Field:  Isoplanatic angle
Description:    This value is logged at the end of each sequence.

# ___oOo___
