/**
 * These classes have been developed for the DFSLog system.
 *
 * @author N. Kornweibel nkornwei@eso.org
 *
 * TO DO:
 * need @revision, and SNIFF info here.
 * 
 */
package org.eso.dfslog;

import javax.swing.*;
import javax.swing.tree.*;
import javax.swing.event.*;
import java.awt.*;
import java.io.*;
import java.awt.event.*;


// JDBC
import java.sql.*;
import com.sybase.utils.Debug;
import java.util.*;


/**
 * DFSLogViewer:
 *
 * A JSplitPane which forms the base panel for the DFSLog Viewing
 * application. The panel creates a DFSLogConnectionServer as well as
 * provides a MessageBar, JTree and Table of recent messages to allow the
 * user to view, report and select message sets.
 *
 * Please see the DFSLog User's Manual for details.
 */


public class DFSLogViewer extends JFrame implements ActionListener,
        TreeSelectionListener {
    private ScrollableLogTable systemErrorTable = null;
    private JPanel sysErrPanel = null;
    private Frame parent = null;

    private JSplitPane splitPane = null ; 
    private MenuBar menuBar = new MenuBar();
    private boolean driverLoaded = false;
    private MessageBar mostRecentMessage;
    private SelectTableModel logModel = null;
    private javax.swing.Timer newMessageTimer = null;
 
    private String preferencesFilePath = ".dfslogrc";

    private MessageDisplay messageDisplay = null;

    private LogEntry logEntryFrame = null;
  
    private Properties appProps = null;

    private DFSLogConnectionServer dfsLogServer = null;

    private JTree tree = null;
    // NK - for debugging Statement sharing.
    private Statement sss  = null;

    private void setPreferencesPath(String s) {
        if (s != null) {
            preferencesFilePath = s;
        }
    }

    private void getProperties(boolean forceUserEdit) {
        FileInputStream instream;
        try {
            instream = new FileInputStream(preferencesFilePath);
        } catch (FileNotFoundException e) {
            instream = null;
        }
        appProps = new Properties();
        if (instream != null) {
            try {
                appProps.load(instream);
            } catch (IOException e) {
                System.out.println("Error loading property file: "
                    +preferencesFilePath);
            }
        }
        if (forceUserEdit || appProps.getProperty("UserName") == null 
            || appProps.getProperty("Password") == null
            || appProps.getProperty("DatabaseServerURL") == null) {
            if (!forceUserEdit) {
                appProps.put("DatabaseServerURL",
                    "jdbc:sybase:Tds:wgsdbp.pl.eso.org:5000");
                appProps.put("UserName", "dfslog_dbo");
                appProps.put("Password", "pdfslog_dbo");
                appProps.put("Driver", "com.sybase.jdbc.SybDriver");
                appProps.put("TreeGraphFile", ".treegraph");
                appProps.put("AlarmLineMessageSelect", 
                    "select msg_id, logdt, priorstr, wsid, compid, logmsg from "
                    +"dfslog..recent_message where priorid < 5 order "
                    +"by logdt desc");
                appProps.put("SystemWideMessageSelect", 
                    "select logdt, priorstr, wsid, compid, logmsg from "
                    +"dfslog..recent_message where priorid < 5 order "
                    +"by logdt desc");
            }
            SimplePropertyEditor r
                = new SimplePropertyEditor(this, "Application Options",
                true, appProps);
            r.pack();
            r.setSize(600, 50+25*appProps.size());
            r.setLocation(400, 400);
            r.show();
            if (r.okSelected()) {
                appProps = r.getProperties();
                try {
                    FileOutputStream outStream = null;
                    outStream = new FileOutputStream(preferencesFilePath);
                    appProps.store(outStream,
                        "DFSLogViewer Properties File");
                    outStream.close();
                } catch (IOException e) {
                    System.out.println("Failed to save property file");
                }
            }
        }
    }



    // implementation of the ActionListener interface
    public void actionPerformed(ActionEvent a) {
        if (a.getSource() == newMessageTimer) {
            // stop the timer while we process the event.
            newMessageTimer.stop();
            if (logModel.update() == true) {
                mostRecentMessage.newUpdate();
            }
            try {
                String newMessage = dfsLogServer.getMostRecentMessage(true);
                if (newMessage != null &&
                    mostRecentMessage.getMessageId()
                        != dfsLogServer.getRecentMessageId())
                {
                    mostRecentMessage.newMessage(newMessage,
                        dfsLogServer.getRecentMessageWorkstation(),
                        dfsLogServer.getRecentMessageComponent(),
                        dfsLogServer.getRecentMessageId());
                }
            } catch (SQLException e) {
                userMessage("Error getting most recent message:\n"
                    +e.toString());
            }
            // restart the timer.
            newMessageTimer.restart();
        } else if (a.getActionCommand() == "Quit") {
            System.exit(0);
        } else if (a.getActionCommand() == "Statement") {
            //NK - for debugging Statement sharing.
            if (sss == null) {
                try {
                    sss = dfsLogServer.getStatement();
                } catch (SQLException e) {
                    System.out.println("Exception getting statement:"
                        +e.toString());
                }
                System.out.println("statement grabbed:"+sss.toString());
            } else {
                try {
                    dfsLogServer.releaseStatement(sss);
                } catch (SQLException e) {
                    System.out.println("statement release error:"+e.toString());
                }
                sss = null;
                System.out.println("statement released");
            }
        } else if (a.getActionCommand() == "Edit Preferences") {
            getProperties(true);
        } else if (a.getActionCommand() == "Selected Rows") {
            generateReport(false);
        } else if (a.getActionCommand() == "Entire View") {
            generateReport(true);
        } else if (a.getActionCommand() == "Add Log Entries") {
            if (logEntryFrame != null) {
                logEntryFrame.setVisible(false);
                logEntryFrame.dispose();
            }
            logEntryFrame = new LogEntry("Enter DFS Messages", dfsLogServer);
            logEntryFrame.pack();
            logEntryFrame.setLocation(400, 400);
            logEntryFrame.setVisible(true);
        } else if (a.getActionCommand() == "goto") {
            // the goto button on the mostRecentMessage panel.
            String selectStatement;
            String frameTitle;
            String mWs = mostRecentMessage.getMessageWorkStation();
            String mComp = mostRecentMessage.getMessageComponent();
            if (mWs != null && mComp != null ) {
                selectStatement = new String(
                    "select * from dfslog..recent_message where wsid = '"
                    +mWs+"'" +" and compid = '"+mComp
                    +"' order by logdt desc");
                frameTitle = new String("View of recent messages from "
                    +mComp+" on " +mWs);
            } else {
                selectStatement = new String(
                    "select * from dfslog..recent_message "
                    +"order by logdt desc");
                frameTitle = new String("View of recent messages");
            }
            displayView(frameTitle, selectStatement);
        }
    }




    public DFSLogViewer(String version, String prefPath) {
        super(version);	

        splitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT,true);

        parent = this;
        setPreferencesPath(prefPath);
        // load the properties.
        getProperties(false);
        dfsLogServer = new DFSLogConnectionServer(appProps);
        dfsLogServer.addLostConnectionListener(new LostConnectionHandler());
        try {
            dfsLogServer.connectToServer();
        } catch (SQLException e) {
            userMessage("Failed to connect to server:\n"+e.toString());
            // Should we exit here?
            System.exit(1);
        }
        // create the nodes of the tree...
        DefaultMutableTreeNode treeRoot = 
            new DefaultMutableTreeNode(new ViewInfo("VLT Dataflow System"));
        createNodes(treeRoot);
   
        // Create the tree and pass it the model.
        tree = new JTree(treeRoot);
 
        tree.getSelectionModel().setSelectionMode
                    (TreeSelectionModel.SINGLE_TREE_SELECTION);
    
        // Register a TreeSelectionListener....
        tree.addTreeSelectionListener(this);
    
        // Create a scroll pane and add the tree to it.
        JScrollPane treeView = new JScrollPane(tree);
    
        // Create the systemError message table (pane).
        systemErrorTable =  new ScrollableLogTable();
        messageDisplay = new MessageDisplay(systemErrorTable.getTable());

        String logSelect = appProps.getProperty("SystemWideMessageSelect");
        if (logSelect == null) {
            logSelect = "select logdt, priorstr, wsid, compid, logmsg from "
                +"dfslog..recent_message "
                +"where priorid < 5 order by logdt desc";
        }
        logModel = new SelectTableModel(dfsLogServer, 
            "dfslog", logSelect);
        logModel.setConnectionServer(dfsLogServer);
        systemErrorTable.setModel(logModel);
        // work around for setDividerLocation().
        systemErrorTable.setPreferredSize(new Dimension(100, 200));

        // add the messageDisplay as a ListSelectionListener.
        ListSelectionModel lsm 
            = systemErrorTable.getTable().getSelectionModel();
        if (lsm != null) {
            lsm.addListSelectionListener(messageDisplay);
        }
 


        treeView.setPreferredSize(new Dimension(100, 400));

        sysErrPanel = new JPanel();
        sysErrPanel.setLayout(new BorderLayout());

        mostRecentMessage = new MessageBar(this);

        String m = null;
        try {
            m = dfsLogServer.getMostRecentMessage(true);
            // set the message id to the current message so that
            // the next message read in is the first one displayed.
            mostRecentMessage.setMessageId(dfsLogServer.getRecentMessageId());
        } catch (SQLException e) {
            userMessage("Error getting most recent message:\n" +e.toString());
        }
        mostRecentMessage.setLastMessage(m);


        JPanel centerPanel = new JPanel(new BorderLayout());
        centerPanel.add("Center", systemErrorTable);
        centerPanel.add("South", messageDisplay);

        sysErrPanel.add("North", mostRecentMessage);
        // sysErrPanel.add("Center", systemErrorTable);
        sysErrPanel.add("Center", centerPanel);
        sysErrPanel.setMinimumSize(new Dimension(100, 200));
        sysErrPanel.setPreferredSize(new Dimension(100, 400));

        treeView.setMinimumSize(new Dimension(100, 200));
	
        splitPane.setOneTouchExpandable(true);	
        splitPane.setTopComponent( sysErrPanel);
        splitPane.setBottomComponent( treeView);

       getContentPane().add("Center", splitPane);
       setupMenus();
       // this pack statement in this location seems to have solved the
       // JSplitPane problem on HP-UX and Linux
       pack(); 
       setMenuBar(menuBar);
       
        // check for new messages every 30 seconds.
        newMessageTimer = new javax.swing.Timer(30000, this);
        newMessageTimer.start();
    } // end of constructor.




    private void generateReport(boolean entireView) {
        Report rep = null;
        int proceed = JOptionPane.YES_OPTION;
        if (entireView) {
            int numRows = 0;
            JTable t = systemErrorTable.getTable();
            if (t != null ) {
                numRows = t.getRowCount();
            }
            if (numRows == 0) {
                proceed = JOptionPane.showConfirmDialog(this,
                    "This report will contain 0 messages\n"+
                    "are you sure you want to continue?",
                    "Please Confirm",
                    JOptionPane.YES_NO_OPTION);
            } else if (numRows > 500) {
                // large reports are time consuming and difficult to
                // handle - prompt the user for confirmation of action.
                proceed = JOptionPane.showConfirmDialog(this,
                    "This report will be large (over 500 messages)\n"+
                    "are you sure you want to continue?",
                    "Please Confirm",
                    JOptionPane.YES_NO_OPTION);
            }
            if (proceed == JOptionPane.YES_OPTION) {
                rep = new ConnServerSQLReport(dfsLogServer,
                    "select logdt, priorstr, wsid, compid, logmsg from "
                    +"dfslog..recent_message where priorid < 5 "
                    +"order by logdt desc");
            }
        } else {
            JTable t = systemErrorTable.getTable();
            int rows[] = t.getSelectedRows();
            if (rows.length == 0) {
                proceed = JOptionPane.showConfirmDialog(this,
                    "This report will contain 0 messages\n"+
                    "are you sure you want to continue?",
                    "Please Confirm",
                    JOptionPane.YES_NO_OPTION);
            } else if (rows.length > 500) {
                // large reports are time consuming and difficult to
                // handle - prompt the user for confirmation of action.
                proceed = JOptionPane.showConfirmDialog(this,
                    "This report will be large (over 500 messages)\n"+
                    "are you sure you want to continue?",
                    "Please Confirm",
                    JOptionPane.YES_NO_OPTION);
            }
            if (proceed == JOptionPane.YES_OPTION) {
                int rowCount = rows.length;
                int minRow = 0;
                if (rowCount > 0) {
                    minRow = rows[0]; 
                }
                int i = 1; 
                while (i < rowCount) {
                    if (minRow > rows[i]) minRow = rows[i];
                    i++;
                }
                rep = new TableModelReport(t.getModel(), minRow, rowCount);
            }
        }

        if (proceed != JOptionPane.YES_OPTION) {
            // the user has cancelled the report.
            return;
        }

        // generate and display the report.
        // display the wait cursor while the new window is built.
        Cursor currentCursor =  getCursor();
        setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));

        ReportViewer r;
        if (entireView) {
            r = new ReportViewer("Report of entire view", rep);
        } else {
            r = new ReportViewer("Report of selected rows", rep);
        }
        r.pack();
        r.setSize(1100, 500);

        // move it away from the top LH corner.
        r.setLocation(160, 200);
        r.setVisible(true);

        // display the original cursor
        setCursor(currentCursor);
    }



    // implement the TreeSelectionListener interface.

    public void valueChanged(TreeSelectionEvent e) {
        if (e.isAddedPath() == false) {
            /* it is the selection we just cleared */
            return;
        }
        DefaultMutableTreeNode node = (DefaultMutableTreeNode)
                           (e.getPath().getLastPathComponent());
        if (node.isLeaf()) {
            ViewInfo nodeInfo = (ViewInfo)node.getUserObject();
            // execute the view according to the String.
            if (nodeInfo != null) {
                if (nodeInfo.getCommandName() != null
                    && nodeInfo.getCommandName().length() > 0) {
                    displayView(nodeInfo.toString(),
                        nodeInfo.getCommandName());
                } else {
                    System.out.println("Nothing configured for:"
                        +nodeInfo.toString());
                }
            }
            tree.clearSelection();
        }
    }

 


    void userMessage(String m) {
        JOptionPane.showMessageDialog(this, m);
    }




    private void createNodes(DefaultMutableTreeNode top) {
        String treeFileName = appProps.getProperty("TreeGraphFile");
        if (treeFileName == null) {
            treeFileName = ".treegraph";
        }
        if (TreeGraphReader.readTreeGraph(top, treeFileName) == false) {
            System.out.println("Failed to read in tree graph: .treegraph");
        }
    } // end of method createNodes().


    private static void printUsage(String version) {
        System.out.println("DFSLog GUI, version "+version);
        System.out.println("options: [-v] | [-pref <preference file>]\n");
    }



    public static void main(String args[]) {

        final String versionString = "v1.6";
        String prefPath = null;

        if (args.length > 0) {
            if (args[0].equals("-pref") && (args.length > 1)) {
                prefPath = args[1];
            } else {
                printUsage(versionString);
                System.exit(0);
            }
        }

	// try to make this structure similar to Gasgano

        //JFrame frame = new JFrame("Data Flow System Log "+versionString);
        DFSLogViewer app = new DFSLogViewer( "Data Flow System Log "+versionString, prefPath);
        // add window listener for exit event..
        app.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });

        // MenuBar mb = new MenuBar();
        // DFSLogViewer app = new DFSLogViewer(frame, prefPath);
        // app.setupMenus(mb);
  
        // frame.getContentPane().add("Center", app);
	// the following statement causes the JSplitPane to fail
        // frame.setMenuBar(mb);
        app.pack();
        app.setSize(1100, 700);
 
        // move it away from the top LH corner.
        app.setLocation(100, 100);
        app.setVisible(true);

    } // end of main().




    private void setupMenus() {
        // Setup the menu items....
        Menu m = new Menu("File");
        MenuItem mi = null;
        // NK - for debugging Statement sharing.
        // mi = new MenuItem("Test Statement");
        // mi.addActionListener(this);
        // m.add(mi);
        mi = new MenuItem("Quit");
        mi.addActionListener(this);
        m.add(mi);
        menuBar.add(m);
        m = new Menu("Report");
        mi = new MenuItem("Selected Rows");
        mi.addActionListener(this);
        m.add(mi);
        mi = new MenuItem("Entire View");
        mi.addActionListener(this);
        m.add(mi);
        menuBar.add(m);
        m = new Menu("Options");
        menuBar.add(m);
        mi = new MenuItem("Edit Preferences");
        mi.addActionListener(this);
        m.add(mi);
        mi = new MenuItem("Add Log Entries");
        mi.addActionListener(this);
        m.add(mi);
    }



    void displayView(String title, String statement) {

        // display the wait cursor while the new window is built.
        Cursor currentCursor =  getCursor();
        setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));

        LogViewer tvFrame
            = new LogViewer(title, dfsLogServer, statement);
        tvFrame.setVisible(false);
        tvFrame.setLocation(135, 150);
        tvFrame.pack();
        tvFrame.setSize(1100, 600);
        tvFrame.setVisible(true);

        // display the original cursor
        setCursor(currentCursor);
    }




    /**
     * LostConnectionHandler:
     *
     * This is an inner class from DFSLogViewer used to display the
     * RetryDialog, ensuring it is displayed only once. If the RetryDialog is
     * terminated by the user (via the quit button), the application will exit.
     * This class implements the LostConnectionListener interface.
     */

    class LostConnectionHandler implements LostConnectionListener {
        boolean retryDialogDisplayed = false;
        public void connectionLost() {
            if (!retryDialogDisplayed) {
                retryDialogDisplayed = true;
                RetryDialog r = new RetryDialog(parent,
                    "Server Connection Lost",
                    true, dfsLogServer);
                r.pack();
                r.setSize(300, 100);
                r.setLocation(400, 400);
                r.show();
                if (r.quitSelected()) {
                    System.exit(1);
                }
                retryDialogDisplayed = false;
            }
        }
    }
} // end of class LogSelector.


// end of file LogSelector.java.
