/**
 * These classes have been developed for the DFSLog system.
 *
 * @author N. Kornweibel nkornwei@eso.org
 *
 * TO DO:
 * need @revision, and SNIFF info here.
 *
 */

package org.eso.dfslog;




import java.io.*;
import java.awt.*;
import java.util.*;
import java.text.*;
import javax.swing.*;
import javax.swing.event.*;

public class MessageDisplay extends JPanel implements
        ListSelectionListener {
    private JTextField msgDate = null;
    private JTextField msgTime = null;
    private JTextField msgPriority = null;
    private JTextField msgSource = null;
    private JTextArea msgMessage = null;
    private JTable table = null;

    MessageDisplay(JTable t) {

        table = t;

        GridLayout g = new GridLayout(3,1);
        g.setHgap(5);
        setLayout(g);

        msgDate = new JTextField(10);
        msgDate.setEditable(false);
        msgDate.setBackground(Color.white);

        msgTime = new JTextField(10);
        msgTime.setEditable(false);
        msgTime.setBackground(Color.white);

        msgPriority = new JTextField(10);
        msgPriority.setEditable(false);
        msgPriority.setBackground(Color.white);

        msgSource = new JTextField(25);
        msgSource.setEditable(false);
        msgSource.setBackground(Color.white);

        JPanel northPanel = new JPanel();
        northPanel.add(new JLabel("Date:"));
        northPanel.add(msgDate);
        northPanel.add(new JLabel("Time:"));
        northPanel.add(msgTime);
        northPanel.add(new JLabel("Priority:"));
        northPanel.add(msgPriority);
        northPanel.add(new JLabel("Source:"));
        northPanel.add(msgSource);
        add(northPanel);

        msgMessage = new JTextArea();
        msgMessage.setEditable(false);
        msgMessage.setLineWrap(true);
        msgMessage.setWrapStyleWord(true);
        add(msgMessage);
    }

    // inform the panel of a new message to display.
    public void valueChanged(ListSelectionEvent e) {
        int selectedRow = -1;
        if (e != null && table != null) {
            ListSelectionModel lsm = (ListSelectionModel)e.getSource();
            if (lsm.isSelectionEmpty()) {
                //no rows are selected
                selectedRow = -1;
            } else {
                selectedRow = lsm.getMinSelectionIndex();
            }
        }
        //selectedRow is selected and we have a table object
        updateDateAndTime(selectedRow);
        updateSource(selectedRow);
        updateMessage(selectedRow);
        updatePriority(selectedRow);
    }




    /**
     * findColumn():
     * find a column by name, return the col number or
     * -1 if the column is not found.
     */

    private int findColumn(String name) {
        int rc = -1;
        int cc = table.getColumnCount();
        for (int i = 0; i < cc; i++) {
            if (name.equalsIgnoreCase(table.getColumnName(i))) {
                rc = i;
                break;
            }
        }
        return rc;
    }



    private void updateDateAndTime(int row) {
        int col = -1;
        String logdt = null;
        String date = null;
        String time = null;
        if (row >= 0) {
            col = findColumn("logdt");
        }
        if (col >= 0) {
            logdt = (String)table.getValueAt(row, col);
        } else {
            logdt = null;
        }
        if (logdt != null && logdt.length() != 0) {
            SimpleDateFormat sdf =
                new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date d = null;
            try {
                d = sdf.parse(logdt);
            } catch (ParseException pe) {
                d = null;
            }
            if (d != null) {
                sdf = new SimpleDateFormat("dd MMM yyyy");
                date = sdf.format(d);
                sdf = new SimpleDateFormat("HH:mm:ss");
                time = sdf.format(d);
            }
        }
        if (date != null) {
            msgDate.setText(date);
        } else {
            msgDate.setText("");
        }
        if (time != null) {
            msgTime.setText(time);
        } else {
            msgTime.setText("");
        }
    }




    private void updateSource(int row) {
        int col = -1;
        StringBuffer source = new StringBuffer("");
        if (row >= 0) {
            String temp = null;
            col = findColumn("wsid");
            if (col >= 0) {
                temp = (String)table.getValueAt(row, col);
                if (temp != null && temp.length() > 0) {
                    source.append(temp+" ");
                }
            }
            col = findColumn("compid");
            if (col >= 0) {
                temp = (String)table.getValueAt(row, col);
                if (temp != null && temp.length() > 0) {
                    source.append(temp+" ");
                }
            }
            col = findColumn("labelid");
            if (col >= 0) {
                temp = (String)table.getValueAt(row, col);
                if (temp != null && temp.length() > 0) {
                    source.append(temp+" ");
                }
            }
        }
        msgSource.setText(source.toString());
    }




    private void updateMessage(int row) {
        int col = -1;
        String msg = new String("");
        if (row >= 0) {
            col = findColumn("logmsg");
            if (col >= 0) {
                msg = (String)table.getValueAt(row, col);
            }
        }
        msgMessage.setText(msg);
    }




    private void updatePriority(int row) {
        int col = -1;
        String pty = new String("");
        if (row >= 0) {
            col = findColumn("priorstr");
            if (col >= 0) {
                pty = (String)table.getValueAt(row, col);
            }
        }
        msgPriority.setText(pty);
    }

} // end of class MessageDisplay.

// end of file MessageDisplay.java
