package org.eso.ohs.core.dbb.client;

// $Id: DbbArrowButton.java,v 1.5 2005/11/24 12:38:26 gdonino Exp $


import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import org.apache.log4j.Logger;
import org.eso.ohs.core.dbb.gui.DbbArrowIcon;
import org.eso.ohs.core.dbb.gui.DbbThreeStateButton;
import org.eso.ohs.core.dbb.sql.DbbSqlChunk;
import org.eso.ohs.core.dbb.sql.DbbSqlOperator;

/**
 * This is an implementation of the DbbWidget abstract class,
 * defining a three state arrow button. This resource should be used
 * when defining sorting widgets.
 * 
 * <br>
 * <br>
 * <br>ChangeLog: cmavros/ddorigoa [OT/1812] 25JUL02 Add call to method 
 *    setSqlOperator() in set() for when an option menu item is set.
 * @author Carlo Boarotto, ESO 13-Jul-1999
 * <p>
 *  
 */
public class DbbArrowButton extends DbbWidget implements ActionListener {

	public static final int DESCENDING = 2;
	public static final int ASCENDING = 1;
	public static final int DISABLED = 0;

	public static final char DESCENDING_CHAR = '2';
	public static final char ASCENDING_CHAR = '1';
	public static final char DISABLED_CHAR = '0';
 
private static final String rcsid = "$Id: DbbArrowButton.java,v 1.5 2005/11/24 12:38:26 gdonino Exp $";
private static Logger stdlog_ = 
    Logger.getLogger( DbbArrowButton.class );
 
  //----------------------------------------
  // Constructors
  //----------------------------------------

  /**
   * Create a DbbArrowButton with its own three state button.
   *
   * @param labeltext	Label text.
   * @param chunk	Attached SQL chunk.
   *
   * @see DbbWidget
   * @see DbbThreeStateButton
   */
  public DbbArrowButton(String labeltext, DbbSqlChunk chunk) {

    this(labeltext, chunk, DISABLED);
    
  }


 /**
   * Create a DbbArrowButton with its own three state button.
   *
   * @param labeltext	Label text.
   * @param chunk	Attached SQL chunk.
   * @param initState   the initialstate of the three state button
   *
   * @see DbbWidget
   * @see DbbThreeStateButton
   */
  public DbbArrowButton(String labeltext, 
			DbbSqlChunk chunk, 
			int initState) {

    super(labeltext, chunk);

    widget_ = new DbbThreeStateButton(new DbbArrowIcon(DISABLED),
				      new DbbArrowIcon(ASCENDING),
				      new DbbArrowIcon(DESCENDING));
    ((DbbThreeStateButton)widget_).set(initState);
    setDefault(get());

    label_.setLabelFor(widget_);
    //label_.setHorizontalAlignment(SwingConstants.RIGHT);

    // Add listeners
    ((DbbThreeStateButton)widget_).addActionListener(this);
  }


  /**
   * Create a DbbArrowButton with its own three state button.
   *
   * @param chunk	Attached SQL chunk.
   *
   * @see DbbWidget
   * @see DbbThreeStateButton
   */
  public DbbArrowButton(DbbSqlChunk chunk) {
    this(chunk.getLabel(), chunk);
  }


  //----------------------------------------
  // Public methods
  //----------------------------------------

  /** 
   * Get the widget value.
   *
   * @return A String value: <code>0</code>, <code>1</code>, <code>2</code>
   */
  public String get() {
    return String.valueOf(((DbbThreeStateButton)widget_).get());
  }


  /**
   * Set the widget value.  
   *
   * @param val Integer value (0,1,2) to describe the state.
   */
  public void set(String val) {
    if(val == null || val.equals(""))
      return;
    String str = val.trim();

    char c = str.charAt(0);
    switch(c) {
    case DISABLED_CHAR:
    case ASCENDING_CHAR:
    case DESCENDING_CHAR:
      Integer i = Integer.valueOf(str.substring(0,1));
      ((DbbThreeStateButton)widget_).set(i.intValue());

      break;
    default:
      ((DbbThreeStateButton)widget_).set(0);
    }
    setSqlOperator();
  }


  /**
   * @return A boolean value: <code>true</code> if it is <em>not</em>
   *         selected, <code>false</code> otherwise.  
   */
  public boolean isEmpty() {
    int val = ((DbbThreeStateButton)widget_).get();
    if(val == 0)
      return true;
    return false;
  }


  //----------------------------------------
  // Event methods
  //----------------------------------------

  /**
   * Listener interface implementation.
   * @param ev	 Event triggering the action.
   */
  public void actionPerformed(ActionEvent ev) {

     setSqlOperator();
     // DbbWidgetEvent has to be released
     fireDbbWidgetAction();
  }

  protected void setSqlOperator() {
    try {
      DbbSqlOperator op = null;

      int val = ((DbbThreeStateButton)widget_).get();
      switch(val) {
      case 2:
        op = new DbbSqlOperator("descending");
        break;
      default:
        op = new DbbSqlOperator("ascending");
        break;
      }

      sqlChunk_.setOperator(op);
    }
    catch(Exception e) {
      stdlog_.warn("",e);
    }
  }

}
