package org.eso.ohs.core.docview.datatrans;


/**
 * A transducer to convert set/get of String values into
 * set/get on a named String property.
 *
 * <p>
 * For example, users will call it's
 * setValue/getValue methods.  Those calls will be translated into
 * calls to setX/getX on the object given to our constructor.
 * The string argument to setValue will be converted to an int
 * before passing to the underlying object's setX method and the
 * result of getX() converted back to a String.
 *
 * <p>
 * $Id: StringAdaptor.java,v 1.1 2004/02/17 12:37:59 tcanavan Exp $
 * <br>
 * @author Bob Kemp
 */

public class StringAdaptor extends ObjAdaptor {

    /**
     * Construct a transducer.
     */
    public StringAdaptor() {
	super(String.class);
    }

    /**
     * Construct a transducer to convert get of String values into
     * getX on a String property of <code>object</code>.
     *
     * If <code>readWrite</code> then likewise for set and setX.
     */
    public StringAdaptor(Object obj, String fieldName) {
	super(String.class, obj, fieldName);
    }

    /**
     * Converts data from a String to a meta-level equivalent of the
     * actual property's type -- in this case a null operation.  Used
     * with reflection to set the new property value.
     * 
     * @param value the new value of the property.
     */
    public Object toMetaLevelObject(String value) {
	return value;
    }


    /**
     * Converts data to a String from the meta-level equivalent of the
     * actual property's type, i.e. from a java.lang.Long
     * to a long int.  Used with reflection to get
     * the current property value.
     *
     * @param value	value of the property.
     */
    public String fromMetaLevelObject(Object obj) {
	return obj == null ? "" : obj.toString();
    }

}

