package org.eso.ohs.core.docview.examples;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.GridLayout;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

import javax.swing.JApplet;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;

import org.eso.ohs.core.docview.datatrans.DocViewObject;
import org.eso.ohs.core.docview.gui.DocView;

/**
 * A simple demo showing two GUI components: two JTextField instances.
 * Each component is wrapped in a DocView, which updates them from the
 * "IntProperty" property of an instance of TestObject.  Updates to the
 * value in each GUI component are likewise stored in the TestObject
 * instance when the component loses focus and thus (indirectly) passed
 * to the other GUI component.
 * 
 * <p>
 * To execute this example as an applet:
 * from the root of the source tree, type
 * <blockquote>
 * appletviewer org.eso.ohs.docview.datatrans/examples/EasyApplet.html
 * </blockquote>
 * or run it from any directory if your CLASSPATH is suitably defined.
 * 
 * To execute this example as a standalone application:
 * from the root of the source tree, type
 * <blockquote>
 * java org.eso.ohs.docview.datatrans.examples.EasyApplet
 * </blockquote>
 * 
 * <p>
 * $Id: EasyApplet.java,v 1.1 2004/02/17 12:38:00 tcanavan Exp $
 * <br>
 * @author Bob Kemp
 */
public class EasyApplet extends JApplet {

    /** 
     * Construct a window containing two JTextField components.
     * Each component is linked through DocView to the "IntProperty" property
     * of an TestObject instance.
     */
    public EasyApplet() {
	Container content = getContentPane();

	content.setLayout(new GridLayout(0, 1));

		// Create DocView instances wrapped around
		//  the JTextField components
	DocView textf = new DocView(new JTextField());
	DocView slider = new DocView(new JTextField());

		// Add the DocView instances to the panel.
		// DocView is a subclass of JPanel and contains
		//  the GUI components.
	content.add(
	    new JLabel(
		"Press TAB to change focus and so force an update"
	    )
	);
	content.add(textf);
	content.add(new JLabel(" "));		// spacer
	content.add(slider);

	TestObject currObj = new TestObject();

		// Link the DocView object (and GUI component)
		//  with the TextObject's property.
	textf.setObjectProperty(currObj, "IntProperty");
	slider.setObjectProperty(currObj, "IntProperty");
    }


    /**
     * Entry point to the program.
     * Creates objects and starts windows.
     * 
     * @param args	Command-line arguments -- ignored
     */
    public static void main(String[] args) {
	EasyApplet applet = new EasyApplet();
	JFrame frm = new JFrame();
	Container content = frm.getContentPane();

	content.setLayout(new BorderLayout());
	content.add(applet, BorderLayout.CENTER);

	frm.setTitle("EasyApplet DocView Demo");
	frm.pack();
	frm.setLocation(770, 90);
	frm.setVisible(true);
    }


    /**
     * Test object implementing DocViewObject interface.
     * Note that addPropertyChangeListener() and
     * removePropertyChangeListener() are required by the
     * DocViewObject.
     */
    public static class TestObject implements DocViewObject {

	private int intProperty_;

	private PropertyChangeSupport support_
			= new PropertyChangeSupport(this);


	public void setIntProperty(int value) {
	    intProperty_ = value;
	    support_.firePropertyChange(null, null, null);
	}

	public int getIntProperty() {
	    return intProperty_;
	}


	/**
	 * Adds a new listener to be notified of changes.
	 * 
	 * @param lnr the listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener lnr) {
	    support_.addPropertyChangeListener(lnr);
	}

	/**
	 * Removes a new listener, which will no longer be notified of changes.
	 * 
	 * @param lnr the listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener lnr) {
	    support_.removePropertyChangeListener(lnr);
	}

    }

}

