package org.eso.ohs.core.gui.baseaction;

/**
 * Utility base class to perform actions on multiple objects,
 * eg duplication of multiple BusinessObject instances.
 * 
 * <p>
 * $Id: IncrementalAction.java,v 1.1 2005/02/11 10:31:49 tcanavan Exp $
 * <p>
 * @author Bob Kemp
 */
public interface IncrementalAction {

    /**
     * Number of steps in the action that are still remaining to be done.
     * 
     * @return number of steps remaining (eg objects to acted upon)
     */
    public int getNumStepsRemaining(int counter);

    /**
     * Method to perform one incremental step of a larger action.
     * 
     * @param stepNo	Counter to indicate the n'th step of a larger action
     */
    public void performStep(int stepNo);

    /**
     * Hook for initialisation of action object.
     */
    public void startOfAction();

    /**
     * Hook for cleanup of action object.
     */
    public void endOfAction();


}


