package org.eso.ohs.core.gui.models;

/**
 * Clearing house for low-level configuration information.
 * All methods are static, use them directly not via an instance.
 * 
 * <p>
 * This class is a little strange: the methods are static but the data
 * is held in a singleton object.  This gives convenience (less to type
 * when calling) but means that we can also serialize it to disk and
 * inheritance still works.
 * 
 * <p>
 * Since deserialization doesn't call the constructors, the default
 * initialisation is not performed when reading from disk.
 * 
 * <p>
 * $Id: ModelsCfg.java,v 1.1 2004/02/17 10:35:21 tcanavan Exp $
 */

public class ModelsCfg {

    protected int maxNameLen_ = -1;
    protected int maxTextLen_ = -1;

    // initialize with this class.
    private static ModelsCfg modelsCfg_ = new ModelsCfg();

    protected ModelsCfg() {
    }

    public static ModelsCfg getCfg() {
	return modelsCfg_;
    }

    public static void setCfg(ModelsCfg cfg) {
	modelsCfg_ = cfg;
    }

    public int getMaxNameLength() {
        return maxNameLen_;
    }

    public int getMaxTextLength() {
        return maxTextLen_;
    }

    public void setMaxNameLength(int max) {
        maxNameLen_ = max;
    }

    public void setMaxTextLength(int max) {
        maxTextLen_ = max;
    }
}


