/**
 * @version $Id: FilePreviewDialog.java,v 1.2 2004/04/08 12:09:51 tcanavan Exp $ 
 * <br>ChangeLog: cmavros 05JUL02 Else missing so "File is null" 
 *                 msg always displayed in output 
 */

package org.eso.ohs.core.gui.widgets;

import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;

import javax.swing.BorderFactory;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.SwingConstants;
import javax.swing.border.TitledBorder;
import javax.swing.plaf.FileChooserUI;
import javax.swing.plaf.basic.BasicFileChooserUI;

import org.apache.log4j.Logger;

public class FilePreviewDialog extends JDialog implements PropertyChangeListener {

    /** Standard log channel */
    private static Logger stdlog_ =
        Logger.getLogger(FilePreviewDialog.class);

    protected SwingFileChooser chooser;
    int returnValue_;
    protected JTextArea textArea;
    protected JLabel commentArea;
    protected JList fileList;
    protected String fileName = null;
    protected static final int LINES = 20;
    protected static final int COLUMNS = 40;
    protected File selectedFile = null;
    private boolean wordWrap = false;

    private String data_ = null;

    public FilePreviewDialog(Frame f, String title) {
        this(f, title, null, false);
    }

    public FilePreviewDialog(Frame f, String title, boolean wordWrap) {
        this(f, title, null, wordWrap);
    }

    public FilePreviewDialog(Frame f, String title, String dir) {
        this(f, title, dir, false);
    }

    public FilePreviewDialog(
        Frame f,
        String title,
        String dir,
        boolean wordWrap) {
        super(f, title, true); // Modal dialog
        chooser = new SwingFileChooser(dir);
        //Java1.4 port fileList = chooser.getList();
        //Java1.4 port fileList.addListSelectionListener(new SelectionListener());
        chooser.addPropertyChangeListener(this);
        chooser.addActionListener(new OpenAction());
        textArea = new JTextArea(LINES, COLUMNS);
        textArea.setEditable(false);
        textArea.setLineWrap(wordWrap);
        textArea.setFont(new Font("Dialog", Font.BOLD, 10));

        JPanel controlPanel = new JPanel();
        controlPanel.setLayout(new BorderLayout());
        controlPanel.add(chooser, "Center");
        JPanel commentPanel = new JPanel();
        commentPanel.setLayout(new BorderLayout());
        commentArea = new JLabel("Select a file...", SwingConstants.LEFT);
        commentPanel.add(new JSeparator(), "North");
        commentPanel.add(commentArea, "South");
        controlPanel.add(commentPanel, "South");
        JPanel textPanel = new JPanel();
        textPanel.setLayout(new BorderLayout());
        textPanel.add(new JScrollPane(textArea), "Center");
        textPanel.setBorder(
            BorderFactory.createTitledBorder(
                BorderFactory.createEtchedBorder(),
                "Preview",
                TitledBorder.CENTER,
                TitledBorder.TOP));
        this.getContentPane().add(controlPanel, "Center");
        this.getContentPane().add(textPanel, "East");
        this.pack();

        this.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent evt) {
                // Dismiss the dialog
                FilePreviewDialog.this.setVisible(false);
            }
        });
    }

    public void propertyChange(PropertyChangeEvent e) {
        String prop = e.getPropertyName();
        if (prop.equals(JFileChooser.SELECTED_FILE_CHANGED_PROPERTY)) {
            //stdlog_.debug("FileChooserEvent " + e);
            File f = (File) e.getNewValue();
            if (f != null) {
                stdlog_.debug("File is " + f.getName());
                fileName = f.getName();
                if (f.canRead()) {
                    chooser.setSelectedFile(f);
                    previewFile(f);
                } else
                    commentArea.setText("File is not readable.");
            }
        }
    }

    public void setDirectorySelectionOnly() {
        chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
    }

    // Get the name of the selected file, or null if none selected
    public String getFileName() {
        return fileName;
    }

    /* Java1.4 port - commented out - not used.
        public void setFilename(String filename) {
            stdlog_.debug("@@@@@@@@@@ Filename = " + filename);
            chooser.setsetFilename(filename);
        }
    */
    public File getSelectedFileHandle() {
        return selectedFile;
    }

    public int getReturnValue() {
        return returnValue_;
    }

    public SwingFileChooser getFileChooser() {
        return chooser;
    }

    public String getValue() {
        return textArea.getText();
    }

    public void addChoosableFileFilter(
        javax.swing.filechooser.FileFilter filter) {
        chooser.addChoosableFileFilter(filter);
    }

    public void setValue(String value) {
        textArea.setText(value);
        textArea.setCaretPosition(0);
        textArea.revalidate();
        textArea.repaint();
        //pack();
    }

    public void rescanCurrentDirectory() {
        chooser.rescanCurrentDirectory();
    }

    protected void previewFile(File f) {
        StringBuffer sb = new StringBuffer();
        char[] buff = new char[64000];
        textArea.setText("");

        try {
            BufferedReader br = new BufferedReader(new FileReader(f));

            while (br.ready()) {
                int nread = br.read(buff, 0, buff.length);
                if (nread <= 0) {
                    break;
                }
                sb.append(buff, 0, nread);
            }
            setValue(sb.toString());
            br.close();

        } catch (Throwable t) {
            commentArea.setText("Failed to read file contents.");
        }
    }

    public class OpenAction implements ActionListener {
        public void actionPerformed(ActionEvent evt) {
            selectedFile = chooser.getSelectedFile();
            String command = evt.getActionCommand();
            if (command.equals("ApproveSelection")) {
                returnValue_ = JOptionPane.OK_OPTION;
            } else {
                returnValue_ = JOptionPane.CANCEL_OPTION;

            }

            setVisible(false);
        }
    }

/*
 * Java1.4: this event source is not obtained through property change event
 * callbacks and so this inner class is no longer needed (does not work).
 * 
    protected class SelectionListener implements ListSelectionListener {
        public void valueChanged(ListSelectionEvent e) {
            if (!e.getValueIsAdjusting()) {
                stdlog_.debug("@@@@@@@@@@@@ Selection Event " + e);
                JList list = (JList) e.getSource();
                File f = (File) list.getSelectedValue();
                if (f != null) {
                    stdlog_.debug("File is " + f.getName());
                    fileName = f.getName();
                    if (f.canRead()) {
                        chooser.setSelectedFile(f);
                        previewFile(f);
                    } else
                        commentArea.setText("File is not readable.");
                }
                //else stdlog_.debug("File is null");
            }
        }
    }
*/
    public void removeFileFilters() {
        //Java1.4 port chooser.removeFileFilters();
        chooser.setAcceptAllFileFilterUsed(true);
    }

    public void setFileFilter(javax.swing.filechooser.FileFilter fileFilter) {
        chooser.setFileFilter(fileFilter);
    }

    public void clearSelection() {
        //Java1.4 port chooser.clearSelection();
        chooser.cancelSelection();
        FileChooserUI ui = chooser.getUI();
        if (ui instanceof BasicFileChooserUI) {
            ((BasicFileChooserUI) ui).setFileName("");
        }
        chooser.setSelectedFile(null);
    }

    public static void main(String[] args) {
        String dir = null;
        if (args.length > 0) {
            dir = args[0];
        }

        JFrame f = new JFrame();
        FilePreviewDialog d = new FilePreviewDialog(f, "File Preview", dir);
        d.show();
        d.dispose();
        stdlog_.debug("Selected file is " + d.getFileName());
        System.exit(0);
    }
}
