package org.eso.ohs.core.gui.widgets;

// $Id: OhsTableSorter.java,v 1.4 2005/11/25 11:13:46 gdonino Exp $

import java.awt.event.InputEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.Vector;

import javax.swing.JTable;
import javax.swing.event.TableModelEvent;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableColumnModel;

import org.apache.log4j.Logger;
import org.eso.ohs.core.dbb.client.AbstractDbbTableModel;



/**
 * DbbTableSorter is an extra class laying between the table (JTable)
 * and its model (DbbTableModel) in order to allow sorting by a column
 * and a criteria lists. <br>
 * It extends TableSorter in order to provide some extra
 * functionalities as sorting by a column and a criteria lists.
 *
 * @author Carlo Boarotto, ESO 29-Sep-1999
 *
 **/

public class OhsTableSorter extends TableSorter {

   /** Standard log channel */
   private static Logger stdlog_ =
       Logger.getLogger( OhsTableSorter.class );

  /**
   * Vector containing Boolean object: true if the corresponding
   * column has to be ascendent, false otherwise.
   */
  Vector columnSortingCriteria = new Vector();;

  //----------------------------------------
  // Constructors
  //----------------------------------------

  /** Call the superclass constructor. */
  public OhsTableSorter() {
    super();
  }

  /** Call the superclass constructor. */
  public OhsTableSorter(AbstractDbbTableModel model) {
    super(model);
  }


  //----------------------------------------
  // Public methods
  //----------------------------------------

  /** 
   * It had to be redefined otherwise the model is listening events
   * coming from the super-super-class TableMap and not from this
   * class.
   *
   * @param model Table model.  
   */
  public void setModel(AbstractDbbTableModel model) {
    this.model = model;
    
    /* Add this listener to the table model, otherwise the table
     * cannot be notified that the columns have been sorted. 
     */
    model.addTableModelListener(this); 
  }

  /**
   * Compare two rows accroding to the sorting criteria specified in
   * the columnSortingCriteria vector. It overrides the super class
   * method to take into account that different columns may have
   * different sorting criteria (ascending or descending).
   *
   * @param row1 First row index.
   * @param row2 Second row index.
   * 
   * @return Integer value: -1 , 0 or 1 if the first row is
   *	     lexicographically less than, equal to, or greater than
   *	     the second one.
   */
  public int compare(int row1, int row2) {
    compares++;

    for (int level = 0; level < sortingColumns.size(); level++) {

      Integer column = (Integer)sortingColumns.elementAt(level);

      int result = compareRowsByColumn(row1, row2, column.intValue());

      if (result != 0) {

	// Begin specialized code: C.Boarotto

	if(level < columnSortingCriteria.size()) {
	  Boolean value = (Boolean)columnSortingCriteria.elementAt(level);
	  ascending = value.booleanValue();
	}
	else
	  ascending = true;

	// End specialized code: C.Boarotto

	return ascending ? result : -result;
      }
    }
    return 0;
  }


  /**
   * Sort by a column list and a list of criteria (ascending or descending).
   *
   * @param column_vector Vector of column indexes.
   * @param column_vector Vector of Boolean objects specifying if the
   *			  column has to be sorted ascending.
   * 
   */
  public void sortByColumns(Vector column_vector, Vector criteria_vector) {

    sortingColumns = column_vector;
    columnSortingCriteria = criteria_vector;

    stdlog_.debug("Sorting " + column_vector);
    
    sort(this);

    stdlog_.debug("Sorting done");

    /* Notify the model that the table has been changed. */
    fireTableChanged(new TableModelEvent(this)); 
  }

    MouseAdapter listMouseListener = null;

    public void removeMouseListenerToHeaderInTable(JTable table) {
        final JTable tableView = table; 
        JTableHeader th = tableView.getTableHeader(); 
        th.removeMouseListener(listMouseListener); 
    }

    /**
     * Override superclass's method
     */
    public void addMouseListenerToHeaderInTable(JTable table) { 
        final TableSorter sorter = this; 
        final JTable tableView = table; 
        tableView.setColumnSelectionAllowed(false); 

        listMouseListener = new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                TableColumnModel columnModel = tableView.getColumnModel();
                int viewColumn = columnModel.getColumnIndexAtX(e.getX()); 
                int column = tableView.convertColumnIndexToModel(viewColumn); 
                if (e.getClickCount() == 1 && column != -1) {
                    //stdlog_.debug("Sorting ..."); 
                    int shiftPressed = e.getModifiers()&InputEvent.SHIFT_MASK; 
                    boolean ascending = (shiftPressed == 0); 
                    sorter.sortByColumn(column, ascending); 
                }
            }
        };
        JTableHeader th = tableView.getTableHeader(); 
        th.addMouseListener(listMouseListener); 
    }

    public Object setValueAt(Object orow, String column_name) {
        // TODO Auto-generated method stub
        return null;
    }   
}
