package org.eso.ohs.dfs;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.CRC32;

/**
 * @author tcanavan
 *
 * To change this generated comment edit the template variable "typecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of type comments go to
 * Window>Preferences>Java>Code Generation.
 */
public class FindingChart extends SimpleStorableObject {

    /** Version id for object serialization */
    static final long serialVersionUID = -4182388435966734083L;

  
    /**
     * Finding chart data
     * This is declared transient so it will not be transmitted 
     * to the appServer and not saved to disk for local storage
     * This varialble will be used when reading data from the database.
     */

    private byte[] fcData;

    /**
     * Filename of the finding chart
     */

    private String fcName;
    
    /**
     * Finding Chart notes
     */
    
    private String fcNotes;

    /**
     * Filetype of finding chart
     */

    private String fcType = "jpg";

    private long checkSum;

    //private long runId;

    private transient ObservingRun obsRun;

    private transient String destDirectory;

    /**
     * Constructor FindingChart.
     * @param findingChart
     */
    public FindingChart(FindingChart findingChart) {
        this.fcName = findingChart.getFcName();
        this.obsRun = findingChart.getObsRun();
        this.checkSum = findingChart.getCheckSum();
        this.fcType = findingChart.getFcType();
        this.fcNotes = findingChart.getFcNotes();
        //this.runId = obsRun.getId();
    }
    /**
     * Constructor FindingChart.
     */
    public FindingChart() {
    }

    /**
       * Constructor for FindingCharts.
       */
    public FindingChart(
        ObservingRun obsRun,
        byte[] fcData,
        String fcName,
        String destDirectory)
        throws IOException {
        this.fcName = fcName;
        this.fcData = fcData;
        this.destDirectory = destDirectory;
        this.obsRun = obsRun;
        CRC32 crc32 = new CRC32();
        crc32.update(fcData);
        this.checkSum = crc32.getValue();
    }

    public void writeFindingChart(long checksumm) throws IOException {
        //stdlog_.debug("Writing file " + );
        File file =
            new File(destDirectory + File.separator + checksumm + "." + fcType);
        if (!file.exists()) {
            FileOutputStream fileOutput = new FileOutputStream(file);
            fileOutput.write(fcData);
            fileOutput.flush();
            fileOutput.close();

        }
        setFcData(null);
    }

    /**
     * Returns the fcName.
     * @return String
     */
    public String getFcName() {
        if (fcName==null)
            return("");
        else
            return fcName;
    }

    /**
     * Returns the fcType.
     * @return String
     */
    public String getFcType() {
        if (fcType==null)
            return("");
        else
            return fcType;
    }

    /**
     * Sets the fcData.
     * @param fcData The fcData to set
     */
    public void setFcData(byte[] fcData) {
        this.fcData = fcData;
    }

    /**
     * Sets the fcName.
     * @param fcName The fcName to set
     */
    public void setFcName(String fcName) {
        this.fcName = fcName;
    }

    /**
     * Sets the fcType.
     * @param fcType The fcType to set
     */
    public void setFcType(String fcType) {
        this.fcType = fcType;
    }

    /**
     * toString Method for Finding Charts
     * Returns FC Name and type
     * @return  String FC Name
     * @see java.lang.Object#toString()
     */

    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("ID \n" + getId());
        sb.append("FC Name \n" + getFcName());
        sb.append("CheckSum \n" + checkSum);
        return sb.toString();
    }

    /**
     * Returns the checkSum.
     * @return long
     */
    public long getCheckSum() {
        return checkSum;
    }

    /**
     * Sets the checkSum.
     * @param checkSum The checkSum to set
     */
    public void setCheckSum(long checkSum) {
        this.checkSum = checkSum;
    }

    /**
     * Method getFcData.
     * @return byte[]
     */
    public byte[] getFcDataLocal(String folderPath) throws IOException {
        // If Finding Chart is null we are dealing with local store.
        if (fcData == null || fcData.length <= 0) {
            return FindingChartCache.getFindingChartData(
                getCheckSum(),
                getFileName(folderPath));
        }
        return fcData;
    }

    public String getFileName(String folderPath) {
        StringBuffer buf = new StringBuffer();
        buf.append(folderPath);
        buf.append(File.separator);
        buf.append(getCheckSum());
        buf.append(".");
        buf.append(fcType);
        return buf.toString();
    }

    /**
     * Returns the fcData.
     * @return byte[]
     */
    public byte[] getFcData() {
        return fcData;
    }

    /**
     * Returns the obsRun.
     * @return ObservingRun
     */
    public ObservingRun getObsRun() {
        return obsRun;
    }

    /**
     * Sets the obsRun.
     * @param obsRun The obsRun to set
     */
    public void setObsRun(ObservingRun obsRun) {
        this.obsRun = obsRun;
    }
    /**
     * @see org.eso.ohs.dfs.StorableObject#postProecess()
     */
    public void postProecess() {
    }

    /**
     * Returns the fcNotes.
     * @return String
     */
    public String getFcNotes() {
        if (fcNotes== null)
            return("");
        else
            return fcNotes;
    }

    /**
     * Sets the fcNotes.
     * @param fcNotes The fcNotes to set
     */
    public void setFcNotes(String fcNotes) {
        this.fcNotes = fcNotes;
    }
    
    
    /**
     * Compares two <code>FindingChart</code> objects, comparing <code>checkSum</code> and <code>fcName</code> properties
     * @param other
     * @return boolean
     */
    public boolean equals(FindingChart other) {
        
        if  ( ( getCheckSum() == other.getCheckSum()  && 
              ( getFcName().compareTo( other.getFcName()) == 0  ) )
             )
            return (true);
        else	
            return(false);
        
    }

}
