package org.eso.ohs.dfs.docviewdatatrans;

import org.eso.ohs.core.docview.datatrans.ObjAdaptor;


/**
 *  A transducer to convert set/get of String values into set/get
 *  on an int property.  The target property's name is given to the
 *  constructor.
 *
 *  <p>
 *  For example, users will call it's
 *  setValue/getValue methods.  Those calls will be translated into
 *  calls to setX/getX on the object given to the constructor.
 *
 *  <p>
 * @version $Id: DegreeAdaptor.java,v 1.1 2004/02/17 12:37:59 tcanavan Exp $
 * <br>
 * @author Bob Kemp
 */

public abstract class DegreeAdaptor extends ObjAdaptor {

    /**
     * Construct a transducer.
     */
    public DegreeAdaptor() {
	super(int.class);
    }

    /**
     * Construct a transducer to convert set/get of String values into
     * setX/getX on an int property of <code>object</code>.
     *
     */
    public DegreeAdaptor(Object obj, String fieldName) {
	super(int.class, obj, fieldName);
    }

    /**
     * Converts data from a String to a meta-level equivalent of the
     * actual property's type, i.e. to a java.lang.Integer
     * representing an int.  Used with reflection to set
     * the new property value.
     *
     * @param value the new value of the property.
     *
     * @return input converted to a millisecond or an empty new Integer
     */
    public Object toMetaLevelObject(String value) {
        int converted_value;

        try{
            converted_value = convertToMilliArcSeconds(value);
        }catch(IllegalArgumentException e){
            // forget about it
            return new Object();
        }
	//return new Integer(convertToMilliArcSeconds(value));
	return new Integer(converted_value);
    }


    /**
     * Converts data to a String from the meta-level equivalent of the
     * actual property's type, i.e. from a java.lang.Long
     * to a long int.  Used with reflection to get
     * the current property value.
     *
     * <br>ChangeLog: cmavros 04/03/02 if exception is thrown return zeros
     * @param value	value of the property.
     */
    public String fromMetaLevelObject(Object obj) {
        try{
	    if (obj == null) {
	        return "00:00:00.0000";
	    }
	    return convertToHMS(((Integer)obj).intValue());
        }
        catch(java.lang.ClassCastException e){
	      return "00:00:00.0000";
        }
    }


    /**
     * Converts a String in the format +UU:MM:SS.sss to milli-arcseconds,
     * where + is an optional sign, UU is hours or degrees, MM is minutes,
     * SS is seconds and sss is millseconds.
     *
     * @param value	value to be converted, represented as a String.
     *
     * @return		input converted to a milliarcseconds
     *
     * @exception       IllegalArgumentException on out of bounds and
     *                                              out of format
     */
    protected abstract int convertToMilliArcSeconds(String value);

    /**
     * Converts milliarcseconds to a String in the format +UU:MM:SS.sss,
     * where + is an optional sign or space, UU is hours or degrees,
     * MM is minutes, SS is seconds and sss is millseconds.
     *
     * @param value	value to be converted, in milliarcseconds
     *
     * @return		input converted to a String
     */
    protected abstract String convertToHMS(int milliSeconds);
}
