package org.eso.ohs.persistence.dao;

import java.io.Serializable;
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.Properties;

import javax.transaction.SystemException;
import javax.transaction.Transaction;
import javax.transaction.TransactionManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.LockMode;
import org.hibernate.dialect.Dialect;
import org.hibernate.engine.SessionImplementor;
import org.hibernate.engine.TransactionHelper;
import org.hibernate.exception.JDBCExceptionHelper;
import org.hibernate.id.Configurable;
import org.hibernate.id.PersistentIdentifierGenerator;
import org.hibernate.id.TableHiLoGenerator;
import org.hibernate.mapping.Table;
import org.hibernate.type.Type;
import org.hibernate.util.PropertiesHelper;

/**
 * An <tt>IdentifierGenerator</tt> that uses a database table to store the
 * last generated value. It is not intended that applications use this strategy
 * directly. However, it may be used to build other (efficient) strategies. The
 * returned type is <tt>Integer</tt>.<br>
 * <br>
 * The hi value MUST be fetched in a seperate transaction to the
 * <tt>Session</tt> transaction so the generator must be able to obtain a new
 * connection and commit it. Hence this implementation may not be used when
 * Hibernate is fetching connections when the user is supplying connections.<br>
 * <br>
 * The returned value is of type <tt>integer</tt>.<br>
 * <br>
 * Mapping parameters supported: table, column
 * 
 * @see TableHiLoGenerator
 * @author Tim Canavan
 */
public class IDGenerator extends TransactionHelper implements
        PersistentIdentifierGenerator, Configurable {
    /* COLUMN and TABLE should be renamed but it would break the public API */
    /** The column parameter */
    public static final String COLUMN = "column";

    /** Default column name */
    public static final String DEFAULT_COLUMN_NAME = "next_hi";

    /** The table parameter */
    public static final String TABLE = "table";

    /** Default table name */
    public static final String DEFAULT_TABLE_NAME = "unique_keys";

    private static final Log log = LogFactory.getLog(IDGenerator.class);

    private String tableName;

    private String columnName;

  //  private String query;

  //  private String update;
    private String keyName;
    int i = 0;
    
    public void configure(Type type, Properties params, Dialect dialect) {
    	System.out.println(i++);
        this.tableName = PropertiesHelper.getString(TABLE, params,
                DEFAULT_TABLE_NAME);
        this.columnName = PropertiesHelper.getString(COLUMN, params,
                DEFAULT_COLUMN_NAME);
        String schemaName = params.getProperty(SCHEMA);
        String catalogName = params.getProperty(CATALOG);
        
        keyName =  PropertiesHelper.getString("pippo", params, "no");
        
        if (tableName.indexOf(dialect.getSchemaSeparator()) < 0) {
            tableName = Table.qualify(catalogName, schemaName, tableName,
                    dialect.getSchemaSeparator());
        }

      /* query = "select " + columnName + " from "
                + dialect.appendLockHint(LockMode.UPGRADE, tableName)
                + dialect.getForUpdateString();

        update = "update " + tableName + " set " + columnName + " = ? where "
                + columnName + " = ?";*/
    }

    public synchronized Serializable generate(SessionImplementor session,
            Object object) throws HibernateException {
        Long id = (Long)doWorkInNewTransaction(session);
        return new Integer((int)id.longValue());
    }

    public String[] sqlCreateStrings(Dialect dialect) throws HibernateException {
        return new String[] {
                "create table " + tableName + " ( " + columnName + " "
                        + dialect.getTypeName(Types.INTEGER) + " )",
                "insert into " + tableName + " values ( 0 )" };
    }

    public String[] sqlDropStrings(Dialect dialect) {
        // return "drop table " + tableName +
        // dialect.getCascadeConstraintsString();
        StringBuffer sqlDropString = new StringBuffer().append("drop table ");
        if (dialect.supportsIfExistsBeforeTableName())
            sqlDropString.append("if exists ");
        sqlDropString.append(tableName).append(
                dialect.getCascadeConstraintsString());
        if (dialect.supportsIfExistsAfterTableName())
            sqlDropString.append(" if exists");
        return new String[] { sqlDropString.toString() };
    }

    public Object generatorKey() {
        return tableName;
    }

    /**
     * Suspend the current transaction and perform work in a new transaction
     */
    public Serializable doWorkInNewTransaction(SessionImplementor session)
            throws HibernateException {

        // This has to be done using a different connection to the
        // containing transaction because the new hi value must
        // remain valid even if the containing transaction rolls
        // back
        TransactionManager tm = session.getFactory().getTransactionManager();
        Transaction surroundingTransaction = null; // for resuming in finally
                                                    // block
        Connection conn = null; // for ressource cleanup
        String sql = null; // for exception
        boolean isJta = tm != null;
        boolean catchedException = false;
        try {
            if (isJta) {
                // JTA environment
                // prepare a new transaction context for the generator
                surroundingTransaction = tm.suspend();
                if (log.isDebugEnabled()) {
                    log.debug("surrounding tx suspended");
                }
                tm.begin();
                // get connection from managed environment
                conn = session.getBatcher().openConnection();
            } else {
                // get connection from the hibernate defined pool
                conn = session.getBatcher().openConnection();
                if (conn.getAutoCommit())
                    conn.setAutoCommit(false);
            }

            Serializable result = getId(conn);

            // commit transaction to ensure updated sequence is not rolled back
            if (isJta) {
                tm.commit();
            } else {
                conn.commit();
            }
            return result;
        } catch (SQLException sqle) {
            catchedException = true;
            if (isJta) {
                try {
                    tm.rollback();
                } catch (Throwable t) {
                    // clean as much as we can
                }
            }
            throw JDBCExceptionHelper.convert(session.getFactory()
                    .getSQLExceptionConverter(), sqle,
                    "could not get or update next value", sql);
        } catch (Exception e) {
            catchedException = true;
            if (isJta) {
                try {
                    tm.rollback();
                    throw new HibernateException(e);
                } catch (SystemException e1) {
                    throw new HibernateException(e1);
                }
            } else {
                throw new HibernateException(e);
            }
        } finally {
            if (isJta) {
                try {
                    session.getBatcher().closeConnection(conn);
                } catch (Exception e) {
                    // swallow it to put JTA in a proper context
                }
                // switch back to surrounding transaction context
                if (isJta && surroundingTransaction != null) {
                    try {
                        tm.resume(surroundingTransaction);
                        if (log.isDebugEnabled()) {
                            log.debug("surrounding tx resumed");
                        }
                    } catch (Exception e) {
                        // do not hide a previous exception
                        if (!catchedException)
                            throw new HibernateException(e);
                    }
                }
            } else {
                session.getBatcher().closeConnection(conn);
            }
        }
    }

    private  Long getId(Connection con) throws SQLException {
        CallableStatement cstmt = null;
        ResultSet rs = null;
        con.setAutoCommit(true);
        System.out.println(con.getAutoCommit());
        cstmt = con.prepareCall("{? = call opc70user..opc_get_key(?)}");

        cstmt.registerOutParameter(1, Types.INTEGER);

        cstmt.setString(2, keyName);

        cstmt.execute();
        cstmt.getMoreResults();
        cstmt.getMoreResults();
        rs = cstmt.getResultSet();
        if (rs != null) {
            rs.next();
            Long id = new Long(rs.getLong(1));
            return id;
        } else {
            throw new SQLException("ID not generated");
        }
    }

    protected Serializable doWorkInCurrentTransaction(Connection arg0, String arg1) throws SQLException {
        // TODO Auto-generated method stub
        return null;
    }

}