package org.eso.ohs.phase2.actions;

import java.awt.Dimension;
import java.awt.event.ActionEvent;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

import org.eso.ohs.core.gui.baseaction.ActionSuperclass;
import org.eso.ohs.core.gui.widgets.ErrorMessages;
import org.eso.ohs.core.gui.widgets.TextDisplayWidget;
import org.eso.ohs.core.utilities.OHSKeys;
import org.eso.ohs.core.utilities.ObjectIOException;
import org.eso.ohs.dfs.CalibrationBlock;
import org.eso.ohs.dfs.ObservingRun;
import org.eso.ohs.dfs.Readme;
import org.eso.ohs.dfs.ReadmeFileReport;
import org.eso.ohs.instruments.Instrument;
import org.eso.ohs.instruments.InstrumentList;
import org.eso.ohs.persistence.AppConfig;
import org.eso.ohs.persistence.Config;
import org.eso.ohs.persistence.Media;
import org.eso.ohs.persistence.OHSPersistence;
import org.eso.ohs.persistence.ObjectContainer;
import org.eso.ohs.persistence.ObjectNotFoundException;

/**
 * Action class to display the finding charts for an ObservationBlock.
 *
 * <p>
 * $Id: ShowReadmeFileHistoryAction.java,v 1.17 2005/11/17 21:47:31 tcanavan Exp $
 * <br>
 * @author Bob Kemp
 */

public class ShowReadmeFileHistoryAction extends ActionSuperclass {


    private ObjectContainer objContainer_;

    
    private JFrame frm_;
    
    private static TextDisplayWidget readmeFileHistory_ = new TextDisplayWidget("Current Readme File");



    /**
     * Constructs a ShowDetailsAction action.
     */
    public ShowReadmeFileHistoryAction(
        ObjectContainer objContainer,
        JFrame frm,String name) {
        super(frm,name);
        objContainer_ = objContainer;
        frm_ = frm;

    }
    
    

    /**
     * Event handler for the ShowDetailsAction action.
     * 
     * @param ev       user-initiated ActionEvent to quit.
     * @throws ObjectNotFoundException
     */
    public void actionPerformedImpl(ActionEvent evt)  {
        OHSPersistence objMgr =
            (OHSPersistence) OHSPersistence.getObjectManager();
        try {
            Long idVal = objContainer_.getSelected();
            if(idVal == null || idVal.longValue()==-1) {
                JOptionPane.showMessageDialog(
                                    frm_,
                                    new Object[] { "No OB Selected." },
                                    "No OB Selected",
                                    JOptionPane.ERROR_MESSAGE);
                                return;         
            }
            Class objType = Config.getCfg().getClassFromId(idVal.longValue());                  
            CalibrationBlock cb  = (CalibrationBlock)objMgr.getBusObj(Media.PHASE2_DB,idVal.longValue(),objType);
            if(cb == null) {
                JOptionPane.showMessageDialog(
                                    frm_,
                                    new Object[] { "No OB Selected." },
                                    "No OB Selected",
                                    JOptionPane.ERROR_MESSAGE);
                                return;         
            }
            Instrument inst = InstrumentList.getInstance().getInstrument(cb.getObsRun().getInstCode(),cb.getObsRun().getIPVersion());
            if(!inst.hasReadmeData()) {
                    JOptionPane.showMessageDialog(
                        objContainer_.getTopLevelAncestor(),
                        new Object[] {
                            "There is no readme configuration available for this observing run.",
                            },
                        "Readme Available",
                        JOptionPane.ERROR_MESSAGE);
                    return;
            }
            OHSPersistence persistence = (OHSPersistence) OHSPersistence.getObjectManager();
            ObservingRun obsRun = cb.getObsRun();
            Readme readme = persistence.populateReadmeFile(Media.PHASE2_DB,obsRun);
            obsRun.setReadme(readme);
            String readmeFileReport = ReadmeFileReport.readmeFileReport(obsRun,AppConfig.getAppConfig().getBoolean(OHSKeys.USGEnabledKey));
            readmeFileHistory_.clearTextArea();
            readmeFileHistory_.setWordWrappping(true);
            readmeFileHistory_.setTextArea(readmeFileReport);
            readmeFileHistory_.setSize(new Dimension(725, 400));
            readmeFileHistory_.setVisible(true);
            readmeFileHistory_.setTitle("Current Readme " + obsRun.getProgId());

            
        } catch (ObjectIOException e) {
            ErrorMessages.announceIOError(frm_, e);
        } catch (ObjectNotFoundException e1) {
            ErrorMessages.announceNoObject(frm_,e1);
        }
    }


}
