package org.eso.ohs.phase2.actions;
import java.awt.Frame;
import java.awt.event.ActionEvent;

import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JOptionPane;

import org.eso.ohs.core.gui.baseaction.ActionSuperclass;
import org.eso.ohs.core.gui.baseaction.IncrementalActionAutomaton;
import org.eso.ohs.core.utilities.ObjUtils;
import org.eso.ohs.persistence.ObjectContainer;
import org.eso.ohs.phase2.visiplot.ChartColorItem;
import org.eso.ohs.phase2.visiplot.ChartFrame;
import org.eso.ohs.phase2.visiplot.IncrementalOBLoadingVisiCalc;
import org.eso.ohs.phase2.visiplot.VPlotOptionsDialog;
import org.eso.ohs.phase2.visiplot.VisiPlotOptions;

/**
 * Action class to execute the visiplots
 * Shows the option dialog, loads the observation blocks, computes the visibility and shows the visiplots
 *
 * @version $Id: VisiplotAction.java,v 1.18 2005/12/01 15:52:35 pnunes Exp $
 * @author Nick Kornweibel
*/

public class VisiplotAction extends ActionSuperclass {
	
	
	private ObjectContainer folderView_;
	private boolean folder_;	
	
	//static ChartFrame chartFrame_ = null;
	protected String sOs_ = System.getProperty("os.name");
	private ChartColorItem[] chartColorItems_;	
	private VisiPlotOptions visiplotOptions_;
	
	public VisiplotAction(ObjectContainer folderView, boolean folder,String name) {
		super((JComponent)folderView, name);
		folderView_ = folderView;      
		folder_ = folder;
		visiplotOptions_ = new VisiPlotOptions();
		
	}
		
	
	/**
	 * Event handler for the Visiplot action.
	 * 
	 * @param ev  user-initiated ActionEvent to quit.
	 */
	public void actionPerformedImpl(ActionEvent evt) {
		Long[] idLongs = null;
		if (!folder_) {
			idLongs = folderView_.getAllSelected();
		} else {
			idLongs = folderView_.getAll();
		}
				
		idLongs = (Long[]) ObjUtils.uniqueOccurrences(idLongs);
		
		// checks if the any OBs are selected
		if (idLongs.length <= 0) {
			JOptionPane
			.showMessageDialog(
					folderView_.getTopLevelAncestor(),
					new Object[] {
						"There are no selected business objects",
						" ",
					"You must first select business objects to report on." },
					"Nothing selected", JOptionPane.ERROR_MESSAGE);			
		} else {
			
			// if there are selected OBs
			// shows the dialog, loads OBs, compute the visibility, and plot them
						
			if (showDialog(true)) {
				generateProgressBar(folderView_,visiplotOptions_,idLongs);
			    
			}
						
		}
	}
	
	/**
     * Load the OB and Calculate the visibility with a progress bar
     */
    private void generateProgressBar(ObjectContainer parent, VisiPlotOptions visiOptions, Long [] obIds ) {
        new IncrementalActionAutomaton(
            new IncrementalOBLoadingVisiCalc(visiOptions, obIds,new ChartFrame(folderView_,visiOptions,chartColorItems_,obIds)),
            (JFrame) parent.getTopLevelAncestor(),
            "Calculating ...");
    }
	
	
	private boolean showDialog(boolean modal) {
        return showDialog((JFrame) folderView_.getTopLevelAncestor(), modal);
    }

    public boolean showDialog(Frame owner, boolean modal) {
    	// build the dialog to show the plotting options
        VPlotOptionsDialog dlg = new VPlotOptionsDialog(owner, modal,false);        
        dlg.showDialog(visiplotOptions_);
        chartColorItems_ = dlg.getChartColorItems();
        return dlg.getSettingsAccepted();
    }
	
	
}

