package org.eso.ohs.phase2.apps.ot.actions;

import java.awt.event.ActionEvent;

import javax.swing.JFrame;

import org.apache.log4j.Logger;
import org.eso.ohs.core.gui.baseaction.ActionSuperclass;
import org.eso.ohs.core.gui.baseaction.IncrementalAction;
import org.eso.ohs.core.gui.baseaction.IncrementalActionAutomaton;
import org.eso.ohs.core.utilities.ObjUtils;
import org.eso.ohs.phase2.apps.ot.gui.MenuGroups;
import org.eso.ohs.phase2.apps.ot.gui.OTViewManager;
import org.eso.ohs.phase2.apps.ot.gui.QueueContainer;
import org.eso.ohs.phase2.apps.ot.gui.QueueView;

/**
 * Action class to create a subdirectory of the selected directory.
 *
 * <p>
 * $Id: CloseQueueAction.java,v 1.9 2005/02/11 10:31:49 tcanavan Exp $
 * <br>
 * Author: Tim Canavan
 */
public class CloseQueueAction extends ActionSuperclass {


   /** Standard log channel */
   private static Logger stdlog_ =
       Logger.getLogger( CloseQueueAction.class );


    private QueueContainer queueContainer_;

    public CloseQueueAction(QueueContainer queueContainer,String name) {
	super((JFrame)queueContainer.getParentFrame(),name);
        queueContainer_ = queueContainer;
       
    }
  

    public void actionPerformedImpl(ActionEvent ev) {               
        long [] queueIds = queueContainer_.getSelectedOpenQueueIds();		   
	new IncrementalActionAutomaton(
            new IncrementalCloseQueue(queueIds),
	    (MenuGroups)queueContainer_,
            "Closing...."	
        );	
    }


 /**
     * Utility class to duplicate a sequence of OBs, one at a time.
     * The user is also given the opportunity to stop the process using
     * a dialog box.
     */
    public class IncrementalCloseQueue implements IncrementalAction {


	/** array of ids of objects to be duplicated */
	private long [] queueIds_;
  
        private int objCount_;


	/**
	 * Constructor.
	 * 
	 * @param frm	    window on which to base any dialog boxes.
	 * @param device    media containing the objects to be duplicated
	 * @param deepCopy  should we duplicate attached objects?
	 * @param dir	    directory containing the ObsBlocks
	 * @param objType   type of object to be duplicated
	 * @param idLongs   array of ids of objects to be duplicated
	 */
	public IncrementalCloseQueue(long [] queueIds) {	   
	    queueIds_  = queueIds;         
	    objCount_ = queueIds.length;	
	    stdlog_.debug("Afer constructing Incremental Open Queue");   		       
	}

       /**
        * Number of steps in the action that are still remaining to be done.
        * 
        * @return number of steps remaining (eg objects to acted upon)
        */
        public int getNumStepsRemaining(int counter) {
            Long [] queueObjs = new Long[queueIds_.length];
	    for(int i=0;i<queueIds_.length;i++) {
                queueObjs[i] = new Long(queueIds_[i]);
            }
            return ObjUtils.howManyNotNull(queueObjs, counter);
        }

        /**
         * Method to perform one incremental step of a larger action.
         * 
         * @param stepNo	Counter to indicate the n'th step of a larger action
         */
        public void performStep(int counter) {           
	    doClose(queueIds_[counter]);                        
        }

        /**
         * Hook for initialisation of action object.
         */
        public void startOfAction() {
        }

        /**
         * Hook for cleanup of action object.
         */
        public void endOfAction() {   
        }


	/**
	 * Utility method to duplicate a given business object
	 * 
	 * @param id	    id of business object to duplicate
	 */
	public void doClose(long queueId) { 
	  OTViewManager manager = OTViewManager.getOTViewMgr();
          QueueView qvm = manager.getQueueView(queueId);   
          if(qvm != null)     
	      qvm.closeQueue();  	             
	}            	   
    }
}

