package org.eso.ohs.phase2.apps.p2pp;

import gnu.regexp.RE;
import gnu.regexp.REException;
import gnu.regexp.REMatch;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.util.BitSet;
import java.util.Hashtable;
import java.util.Properties;
import java.util.Stack;
import java.util.TimeZone;
import java.util.Vector;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

import org.apache.log4j.Logger;
import org.eso.ohs.core.docview.datatrans.AdaptorFactory;
import org.eso.ohs.core.gui.models.ModelsCfg;
import org.eso.ohs.core.gui.widgets.ErrorMessages;
import org.eso.ohs.core.gui.widgets.LoginDialog;
import org.eso.ohs.core.gui.widgets.OutOfMemoryReport;
import org.eso.ohs.core.gui.widgets.SplashScreen;
import org.eso.ohs.core.gui.widgets.StatusDialog;
import org.eso.ohs.core.utilities.ConnectionPool;
import org.eso.ohs.core.utilities.ExtFileList;
import org.eso.ohs.core.utilities.FileIOUtils;
import org.eso.ohs.core.utilities.NotASCIIException;
import org.eso.ohs.core.utilities.OHSKeys;
import org.eso.ohs.core.utilities.ObjConfig;
import org.eso.ohs.core.utilities.ObjectIOException;
import org.eso.ohs.core.utilities.SystemStatus;
import org.eso.ohs.core.utilities.SystemStatusListener;
import org.eso.ohs.dfs.BusinessObject;
import org.eso.ohs.dfs.CalibrationBlock;
import org.eso.ohs.dfs.ConstraintSet;
import org.eso.ohs.dfs.FindingChartCache;
import org.eso.ohs.dfs.ObservationBlock;
import org.eso.ohs.dfs.ObservationDescription;
import org.eso.ohs.dfs.ObservingRun;
import org.eso.ohs.dfs.Summary;
import org.eso.ohs.dfs.Target;
import org.eso.ohs.instruments.InstrumentInitialiser;
import org.eso.ohs.instruments.InstrumentList;
import org.eso.ohs.instruments.TemplateSignature;
import org.eso.ohs.instruments.TemplateVersionInfo;
import org.eso.ohs.p2pp.Folder;
import org.eso.ohs.persistence.AppConfig;
import org.eso.ohs.persistence.AuthenticatingStorageMgr;
import org.eso.ohs.persistence.Config;
import org.eso.ohs.persistence.DirectoryNode;
import org.eso.ohs.persistence.EVMStorageMgr;
import org.eso.ohs.persistence.LocalDirMgr;
import org.eso.ohs.persistence.Media;
import org.eso.ohs.persistence.OHSAdaptorFactory;
import org.eso.ohs.persistence.OHSApplication;
import org.eso.ohs.persistence.ObjectAuthorisationException;
import org.eso.ohs.persistence.ObjectListener;
import org.eso.ohs.persistence.ObjectNotFoundException;
import org.eso.ohs.persistence.ProtectingStorageMgr;
import org.eso.ohs.persistence.StorageManager;
import org.eso.ohs.persistence.dbase.phase1.OpcDbaseMgr;
import org.eso.ohs.persistence.dbase.phase2.DBInstrumentListFactory;
import org.eso.ohs.persistence.dbase.phase2.DbaseMgr;
import org.eso.ohs.phase2.apps.p2ppAppServer.RmiLocalManager;
import org.eso.ohs.phase2.icdVcs.CCSConnect;
import org.eso.ohs.phase2.icdVcs.IcdVcsCfg;

/**
 * The main program, i.e. the initially executed class.
 *
 * @version $Revision: 1.50 $
 * @author cmavros 11-03-2002 1700/OT
 * <br>ChangeLog: cmavros 08May02 [1426/1501/1631/OT] Add call to offsetFontSize()
 * <br>ChangeLog: cmavros 20JUNE02 [1652/P2PP] Read proxy settings.
 * <br>ChangeLog: cmavros 26JUNE02 Wrap DbaseMgr() with EVMStorageMgr class.
 */
public class P2PP extends OHSApplication {

    /** CVS version id to let us double check a JAR file's version! */
    public static final String cvsID_ =
        "$Id: P2PP.java,v 1.50 2005/11/17 12:30:14 tcanavan Exp $";

    /** Standard log channel */
    private static Logger stdlog_ = Logger.getLogger(P2PP.class);

    /** width of the left-hand border in which not to place the main window */
    private static final int BORDER_WIDTH_ = 30;

    /** height of the border at the top in which not to place the main window */
    private static final int BORDER_HEIGHT_ = 30;

    /** Support for handling PropertyChangeEvent */
    // private static EventListenerList listenerList_ = new EventListenerList();

    /** Ensure OutOfMemoryReport class is loaded and static initialisers run */
    private static OutOfMemoryReport outOfMemDialog_;

    /** Ensure OutOfMemoryReport class is loaded and static initialisers run */
    public static LockMgr lockMgr;

    /** remember the userID of the current session */
    private static int loc_userID;

    /** don't pop up cache create msg twice */
    private static boolean cacheCreatePopedUp = false;

    private static final int SUFFIX_LEN = 4;

    /**
     * Used to record if a dialog is currently being displayed, to avoid
     * the display of multiple dialogs simulatneously.
     */
    private static boolean showingDialog_ = false;

    private static final double maxSizeRatio = 0.9; // window / screen size ratio
    //private static final Dimension screen =
    //    Toolkit.getDefaultToolkit().getScreenSize();

    /** Constructor
     *
     * <br>ChangeLog: A M Chavan, 26-Jun-2001: creation from main()
     */
    protected P2PP(String[] args) {

        // TODO this constructor is over 300 lines long

        // Initialize this application
        OHSApplication p2pp = getApplication();
        p2pp.init(
            "Phase II Proposal Preparation System",
            "P2PP",
            P2PPVersion.getVersion());

        Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
        InstrumentInitialiser instrInit;
        AppConfig appcfg = null;
        Config cfg = null;
        JFrame p2ppWin;

        SplashScreen splash =
            new SplashScreen(OHSApplication.getShortDesc() + " loading...");
        splash.setVisible(true);

        TimeZone.setDefault(TimeZone.getTimeZone("UTC"));

        try {
            Thread.sleep(100);
        } catch (InterruptedException e) {
            // ignore
        }

        try {
            AppConfig.setAppConfig(new AppConfig());
            AppConfig.getAppConfig().setStandardOHSKeys("config");
            readCfgs();
            //stdlog_.info("CONFIG:\n"+AppConfig.getAppConfig().toString());
            //ChangeLog 21June02 Requested output from the Test group.
            stdlog_.info(
                "Cache Directory: " + AppConfig.getAppConfig().getCacheDir());
            stdlog_.info("Impex Directory: " + AppConfig.getAppConfig().getExpDir());
            stdlog_.info("Server: " + AppConfig.getAppConfig().getDbServer());

            setupSubsystems();
            initObjInfo();
            File objClassFile =
                new File(AppConfig.getAppConfig().getConfigDir(), "objClass.dat");
            Target.initialiseBusinessObjects(objClassFile);
        } catch (IOException e) {
            JOptionPane.showMessageDialog(
                null,
                e.getMessage(),
                "Error in config file",
                JOptionPane.ERROR_MESSAGE);
            stdlog_.error("", e);
            ;
            System.exit(0);
        }

        appcfg = AppConfig.getAppConfig();
        cfg = Config.getCfg();

        String version = OHSApplication.getVersion();

        if (version == null || version.length() <= 0) {

            JOptionPane.showMessageDialog(
                null,
                "Insufficent version info to run this application",
                "Error no version information",
                JOptionPane.ERROR_MESSAGE);
            System.exit(0);

        }

        OHSApplication.checkDbFileExists();

        if (!appcfg.dbCfgCanRead()) {

            JOptionPane.showMessageDialog(
                null,
                "Cannot read config file p2pp-db.cf\n P2PP cannot continue",
                "File Read Permission Error : p2pp-db.cf",
                JOptionPane.ERROR_MESSAGE);
            System.exit(0);
        }

        if (!appcfg.hasConnectInfo()) {

            JOptionPane.showMessageDialog(
                null,
                "Insufficent connection info to run application",
                "Error no connection information",
                JOptionPane.ERROR_MESSAGE);
            System.exit(0);

        }

        checkInstrumentDirectories(appcfg);
        String ipCacheDir = AppConfig.getAppConfig().getIPVersionIPCache();

        if (ipCacheDir != null && ipCacheDir.length() > 0) {
            checkDirectory(new File(ipCacheDir), true, true);
        }

        if (!AppConfig.getAppConfig().isIPVersioningSingleIPMode()
            && (ipCacheDir == null || ipCacheDir.length() == 0)) {
            JOptionPane.showMessageDialog(
                null,
                new Object[] {
                    "No IP cache folder is configured.",
                    " ",
                    "IP Cache Directory Keyword: ",
                    "    " + OHSKeys.IPVersioningIPCache,
                    " ",
                    "Cannot continue!" },
                "Configuration Error",
                JOptionPane.ERROR_MESSAGE);
            System.exit(0);
        }
        if (AppConfig.getAppConfig().isIPVersioningSingleIPMode()
            && AppConfig.getAppConfig().getIPVersioningAutodownloadIPEnabled()) {
            JOptionPane.showMessageDialog(
                null,
                new Object[] {
                    "Single IP Mode may not be enabled along with automatic IP download.",
                    " ",
                     "Automatic IP Download Keyword: ",
                    "    " + OHSKeys.IPVersioningAutodownloadIP,
                    "Single IP Mode Keyword: ",
                    "    " + OHSKeys.IPVersioningSingleIPModeEnabled,
                    " ",
                    "Cannot continue!" },
                "Configuration Error",
                JOptionPane.ERROR_MESSAGE);
            System.exit(0);
        }

        // Initialize GUI
        setLookAndFeel();
        offsetFontSize(appcfg);
        setDefaultGUIResources();
        setupConnectionPool();
        stdlog_.debug("************* MAX FINDING CHARTS " + appcfg.getMaxFindingCharts());
        stdlog_.debug("************* MAX FINDING CHARTS SIZE " + appcfg.getMaxFindingChartSize());

        FindingChartCache.setMapSize(appcfg.getMaxFindingCharts());
        try {
            // Ensure OutOfMemoryReport is loaded and initialised.
            outOfMemDialog_ = new OutOfMemoryReport();
            lockMgr = new LockMgr();

            StorageManager phase1dbmgr = createStorageManager(Media.PHASE1_DB);
            StorageManager phase2dbmgr = createStorageManager(Media.PHASE2_DB);

            splash.setVisible(false);
            splash.dispose();
            splash = null;
            Persistence.startup();
            Persistence objMgr = Persistence.getInstance();


            int loginStatus = login(null, phase1dbmgr);

            if (loginStatus < 0) {
                System.exit(0);
            }
            // Moved from above the login, where it used to be
            // as we need to know who is logged in
            // before we can know what InstrumentListFactory to load.
            boolean ipMode = AppConfig.getAppConfig().isIPVersioningSingleIPMode();
            String instDir = AppConfig.getAppConfig().getInstrumDir();
            if (cfg.isInOperationsMode()) {
                if (AppConfig.getAppConfig().shouldUseAppServer()) {
                    JOptionPane.showMessageDialog(
                        null,
                        new Object[] {
                            "Automatic IP Download for Operations Mode",
                            "is enabled in DIRECT mode only." },
                        "Warning",
                        JOptionPane.WARNING_MESSAGE);
                } else {
                    if (ipCacheDir != null && ipCacheDir.length() > 0) {
                        /*
                         * Load the DBInstrumentListFactory() if set in the configuration.
                         */
                        if (!AppConfig.getAppConfig().isIPVersioningSingleIPMode()
                            && AppConfig
                                .getAppConfig()
                                .getIPVersioningAutodownloadIPEnabled()) {
                            /*
                             * Code here assumes that the configuration is correct - i.e. that
                             * the ipCacheDir exists in the configuration. This is tested above.
                             */
                            InstrumentList.setInstrumentListFactory(
                                new DBInstrumentListFactory(
                                    ipMode,
                                    instDir,
                                    ipCacheDir,
                                    AppConfig.getAppConfig().getDbUserName(),
                                    AppConfig.getAppConfig().getDbPassword()));
                        }
                    }
                }
            } else {
                if ((ipCacheDir != null && ipCacheDir.length() > 0)
                    && !AppConfig.getAppConfig().isIPVersioningSingleIPMode()) {
                    /*
                     * Load the P2PPInstrumentListFactory if set in the configuration.
                     * Code here assumes that the configuration is correct - i.e. that
                     * the ipCacheDir exists in the configuration. This is tested above.
                     */
                    InstrumentList.setInstrumentListFactory(
                        new P2PPInstrumentListFactory(ipMode,instDir,ipCacheDir));
                }
            }
            instrInit = new InstrumentInitialiser(ipMode,instDir,ipCacheDir);
            instrInit.start();
            if (!instrInit.checkInstrumentsLoaded()) {
                JOptionPane.showMessageDialog(
                        null,
                        "There are no Instrument Packages in folder\n" + instDir,
                        "No Instrument Packages found",
                        JOptionPane.ERROR_MESSAGE);

                System.exit(0);
            }            
            if (instrInit.checkInstrumentsVersion()) {
                stdlog_.debug("All instrument packages have correct version");
            }

            
            displayInstrumentErrorInfo();


            if (!Config.getCfg().isInOperationsMode()) {
                File cacheDirFile = new File(appcfg.getCacheDir());
                String cacheDir = cacheDirFile.getAbsolutePath();

                // NOTE: Must add AutoSaver as an ObjectListener as soon
                //       as possible.  Definitely before manipulating
                //       Folders!!  Otherwise, a Folder may not be saved
                //       because AutoSaver did not notice it's creation !!

                ObjectListener ol = FolderFactory.getObjectListener();

                objMgr.addObjectListener(ol);
                objMgr.setStorageManager(
                    Media.LOCAL,
                    new LocalDirMgr(cacheDir, cfg.getUserName()));
                chk4cache_create(cacheDir);
            }

            phase1dbmgr.setUserId(cfg.getUserName());
            phase2dbmgr.setUserId(cfg.getUserName());

            objMgr.setStorageManager(Media.PHASE1_DB, phase1dbmgr);
            objMgr.setStorageManager(Media.PHASE2_DB, phase2dbmgr);

            p2pp.setInstance(Persistence.getInstance());

            if (cfg.isInOperationsMode()) {
                p2ppWin = DbaseWindow.getDbaseWindow(Media.DBASE);
            } else {
                if (loginStatus == 0) {
                    try {
                        downloadObservingRuns();
                    } catch (ObjectIOException e) {

                        stdlog_.error(e); // Leave as user support info.
                        JOptionPane.showMessageDialog(
                            null,
                            new Object[] {
                                "Details of your Observing runs"
                                    + " could not be downloaded.",
                                "This is usually because the server at ESO"
                                    + " cannot be contacted,"
                                    + " for some reason.",
                                " ",
                                "Check your Internet connection to ESO"
                                    + " and try again.",
                                "If error persists, contact ESO User Support.",
                                " ",
                                "Fatal error during initialisation" },
                            "Fatal Error",
                            JOptionPane.ERROR_MESSAGE);
                        System.exit(1);
                    }
                }
                /** Force all folders to be loaded and hence
                * initialise the DirectoryNode hierarchy for LOCAL.
                */
                FolderFactory.loadBaseObjects(Media.LOCAL);
                /** CCS initialisation moved to after download observinf runs to
                *  prevent occasionally freezes. If this ever happens again
                *  press CTRL \ to get a stack trace from the JVM.
                */
                if (appcfg.getCCSEnabled() && appcfg.getCCSServer() != null) {

                    // BOB connection, no MaskListener
                    // A M Chavan, 03-Feb-01
                    CCSConnect con = new CCSConnect();
                    boolean t = con.startCcs("org.eso.ohs.phase2.icdVcs.BOB");
                    appcfg.setCcsActive(t);
                } else {
                    stdlog_.info("Access to BOB is not configured.");
                }
                p2ppWin = new MainWindow(Media.LOCAL);
            }

            // set window dimensions
            Dimension window = setScreenSize(p2ppWin);

            // set window location
            // This needs refining.  The centre of the window
            //  should be on the right of the screen but not
            //  hanging off the edge of it.
            int x = (5 * screen.width / 7) - (window.width / 2);
            if (x + window.width > screen.width) {
                x = screen.width - window.width;
            }
            if (x < BORDER_WIDTH_) {
                x = BORDER_WIDTH_;
            }

            int y = screen.height / 3 - (window.height / 2);
            if (y + window.height > screen.height) {
                y = screen.height - window.height;
            }
            if (y < BORDER_HEIGHT_) {
                y = BORDER_HEIGHT_;
            }
            p2ppWin.setLocation(x, y);
            p2ppWin.setVisible(true);

        } catch (Exception e) {
            stdlog_.error("", e);
            ErrorMessages.announceIOError(null, e);
            JOptionPane.showMessageDialog(
                null,
                "Fatal error during initialisation",
                "Fatal Error",
                JOptionPane.ERROR_MESSAGE);
            System.exit(1);
        }
    }

    /**
     * Set singleton instances of required implementation classes.
     */
    protected void setupSubsystems() throws IOException {
        Config.setCfg(new MyPersistCfg());
        IcdVcsCfg.setCfg(new MyIcdVcsCfg());
        ModelsCfg.getCfg().setMaxTextLength(
            AppConfig.getAppConfig().getPersistenceMaxTextLength());
        ModelsCfg.getCfg().setMaxNameLength(
            AppConfig.getAppConfig().getPersistenceMaxNameLength());
        AdaptorFactory.setInstance(new OHSAdaptorFactory());
    }

    /**
     * Read the required config files into AppConfig.
     * This method is public and static so it may be called from Unit Tests.
     */
    public static void readCfgs() throws IOException {
        AppConfig ac = AppConfig.getAppConfig();
        ExtFileList extList = new ExtFileList(ac.getConfigDir(), ".cf");
        if (extList.exists("p2pp-db.cf")) {
            File dbFile = extList.getFileHandle("p2pp-db.cf");
            // ac.setupDbDirectConfig(OHSKeys.DBDirectSubConfig, dbFile);
            // need to put db config file in root dir (not in a sub config) or it can not
            // be overridden from the users config file.
            ac.setupDbDirectConfig("", dbFile);
        }
        if (extList.exists("server.cf")) {
            File srvFile = extList.getFileHandle("server.cf");
            try {
                ac.addParamfile(srvFile.getAbsolutePath());
            } catch (NotASCIIException e) {
                throw new IOException(e.getMessage());
            }
        }
        // String currDir = System.getProperty("user.dir");
        File siteCf = extList.getFileHandle("site.cf");
        if (siteCf != null) {
            if (siteCf.exists() && siteCf.canRead()) {
                try {
                    ac.addParamfile(siteCf.getAbsolutePath());
                    String proxyHost = ac.getAppServerHttpProxyHost();
                    String port = ac.getAppServerHttpProxyPort();
                    if (proxyHost != null && port != null) {
                        stdlog_.info("proxyHost = " + proxyHost + " port = " + port);
                        System.getProperties().put("proxyHost", proxyHost);
                        System.getProperties().put("proxyPort", port);
                    }
                } catch (NotASCIIException e) {
                    //throw new IOException(e.getMessage());
                    // cmavros 11-03-2002 1700/OT
                    int rtn =
                        JOptionPane.showConfirmDialog(
                            null,
                            "Syntax Error while reading:\n"
                                + siteCf
                                + "\non the following lines:"
                                + "\n\n"
                                + e.getMessage()
                                + "\nIgnoring syntax errors can cause undesirable results."
                                + "\n\nPlease quit and correct the syntax errors before continuing."
                                + "\n\nDo you want to quit?",
                            "Syntax Error",
                            JOptionPane.YES_NO_OPTION);
                    if (rtn == JOptionPane.YES_OPTION) {
                        System.exit(0);
                    }
                }
            }
        }
        if (!ac.getStartAppServer()) {
            File userCf = new File(ac.getHomeDir() + File.separator + ".p2pp.cf");
            if (userCf.exists() && userCf.canRead()) {
                stdlog_.debug("!!!!!!!!!!!! >>>>>>>>> User Config");
                // the User CF file over writes settings in the site.cf
                // file - these settings are stored under a
                // UserOverrideKey subconfig
                // and used to over write settings when required.
                // Examine prependBase() for details on the effects of
                // the oser-ridden parameters.
                try {
                    ac.addParamfile(
                        userCf.getAbsolutePath(),
                        OHSKeys.UserOverrideKey);
                    ac.processOverrides();
                } catch (NotASCIIException e) {
                    throw new IOException(e.getMessage());
                }
            }
        }  
        // Here we supersede the contents of the CCS config file, if
        // any, with the value of the "ccs.wanted" property.
        // Under Unix, that can be selected using the "-noccs"
        // command line option.
        //
        // A M Chavan, 17-Jan-2000

        if (ac.getCCSEnabled() && "false".equals(System.getProperty("ccs.wanted"))) {
            ac.setValue(OHSKeys.CcsConnEnabledKey, false);
        }
    }

    /**
     * Set the required business object settings into AppConfig.
     * This method is public and static so it may be called from Unit Tests.
     */

    public static void initObjInfo() {
        AppConfig appCfg = AppConfig.getAppConfig();
        appCfg.putObjCfg(new ObjConfig(ConstraintSet.class, new String[] {
            // Displayed column names
            "Id",
                "Name",
                "Airmass",
                "Sky Transparency",
                "Lunar Illumination",
                "Seeing",
                "Moon Distance" },
                new String[] { // Names of displayed properties
            "Id",
                "Name",
                "Airmass",
                "SkyTransparency",
                "FractionalLunarIllumination",
                "Seeing",
                "MoonAngularDistance" },
                new String[] { // Editable property names
            "Name",
                "Airmass",
                "FractionalLunarIllumination",
                "Seeing",
                "MoonAngularDistance" }));

        appCfg.putObjCfg(new ObjConfig(Target.class, new String[] {
            // Displayed column names
            "Id",
                "Name",
                "Ra",
                "Dec",
                "Equinox",
                "Epoch" },
                new String[] { // Names of displayed properties
            "Id",
                "Name",
                "RA",
                "Declination",
                "Equinox",
                "Epoch" },
                new String[] { // Editable property names
            "Name", "RA", "Declination", "Equinox", "Epoch" }));

        appCfg.putObjCfg(new ObjConfig(ObservationBlock.class, new String[] {
            // Displayed column names
            "Id",
                "Name",
                "DbaseId",
                "Status",
                "Target",
                "OD",
                "CS",
                "Acquisition",
                "FindingCharts",
                "EphemerisFile"
                },
                new String[] { // Names of displayed properties
            "Id",
                "Name",
                "DbaseId",
                "Status",
                "Target",
                "Od",
                "ConstraintSet",
                "TemplateSignature",
                "FindingCharts",
                "EphemerisFile"},
                new String[] {
        }));

        appCfg.putObjCfg(new ObjConfig(CalibrationBlock.class, new String[] {
            // Displayed column names
            "Id",
                "Name",
                "DbaseId",
                "Status",
                "OD" },
                new String[] { // Names of displayed properties
            "Id", "Name", "DbaseId", "Status", "Od" }, new String[] {
        }));

        appCfg.putObjCfg(new ObjConfig(ObservationDescription.class, new String[] {
            // Displayed column names
            "Id",
                "Name",
                "Instrument" },
                new String[] { // Names of displayed properties
            "Id", "Name", "Instrument" }, new String[] { // Editable property names
            "Name" }));
            
            

            

        appCfg.putObjCfg(new ObjConfig(ObservingRun.class, new String[] {
            // Displayed column names
            // Period is required by MainWindow.Phase1Information
            "Id",
                "Period",
                "Title" },
                new String[] { // Names of displayed properties
            // Period is required by MainWindow.Phase1Information
            "Id", "Period", "Title" }, new String[] { // Editable property names
        }));
    }

    /**
     * The main() method for this program -- execution starts here.
     *
     * @param args array of arguments passed to this program by the
     *            operating system.
     */
    public static void main(String[] args) {
        /* P2PP p2pp = */
        new P2PP(args);
    }

    /**
     * Quit the application gracefully without asking the user.
     * Used by askAndQuit() and for OutOfMemoryError shutdowns
     */
    public static void quitWithoutAsking() {
        Persistence objMgr = Persistence.getInstance();

        if (objMgr != null) {
            objMgr.shutdown();
        }

        // Deprecated in 1.2 but without it, exiting is V.slow on HP
        // commented out for port ot 1.4 Runtime.getRuntime().runFinalizersOnExit(false);
        lockMgr.unlockLocalStorage(Config.getCfg().getUserName());

        System.exit(0);
    }

    /**
     * Asks the user if they really want to quit the application and, if so,
     * shuts down and exits.
     */
    public static void askAndQuit() {
        // if there is already a dialog displayed, do not show another one....
        if (showingDialog_) {
            return;
        }
        // there is not a dialog being displayed - it is safe to display one.
        showingDialog_ = true;
        int result =
            JOptionPane.showConfirmDialog(
                MainWindow.getPrincipalWindow(),
                "Would you like to quit now?",
                "Quit Now?",
                JOptionPane.YES_NO_OPTION);

        if (result == JOptionPane.YES_OPTION) {
            quitWithoutAsking();
        }
        showingDialog_ = false;
    }

    /**
     * Downloads observing runs from the database and saves them in the
     * local storage area.   This method will only be called once when the
     * system is setting up the local storage area but until it completes
     * successfully local storage is unusable.
     *
     * @exception ObjectIOException
     *      if there was an I/O error reading the object.
     * @exception ObjectNotFoundException
     *      if there is no ObservingRun with the given id on this medium.
     * <br>ChangeLog: A M Chavan, 01-Feb-2000, [no SPR] fixed a small bug,
     *                                  changed wording of an error message.
     */
    public static void downloadObservingRuns()
        throws ObjectNotFoundException, ObjectIOException {
        Persistence objMgr = Persistence.getInstance();
        DirectoryNode dbRoot = objMgr.getRoot(Media.PHASE1_DB);
        Summary[] summ = objMgr.listObjects(Media.PHASE1_DB, dbRoot);
        boolean downloadedAnObservingRun;
        final StatusDialog downloadStatus =
            new StatusDialog(
                null,
                "Downloading Observing Runs, this may take a few minutes.");
        downloadStatus.show();

        downloadedAnObservingRun =
            Phase1Information
                .refreshObsRuns(summ, new Phase1Information.MessageListener() {
            public void infoMessage(String msg) {
                downloadStatus.setMessage(msg);
            }
            public void errorMessage(String msg) {
                JOptionPane.showMessageDialog(
                    null,
                    new Object[] { "Error downloading Observing Runs", "", msg,
                        "Please contact ESO User Support Group."},
                    "Download Error",
                    JOptionPane.ERROR_MESSAGE);
            }
        });

        downloadStatus.setVisible(false);
        if (!downloadedAnObservingRun) {
            JOptionPane.showMessageDialog(
                null,
                new Object[] {
                    "You appear not to have any Observing Runs allocated",
                    "but without Observing Runs you cannot do anything.",
                    " ",
                    "If this is an error, please contact ESO User Support Group.",
                    " ",
                    "If you want to learn how to use this program, please",
                    "see the user manual for details of the tutorial account." },
                "No Observing Runs",
                JOptionPane.ERROR_MESSAGE);
            System.exit(1);
        }
        lockMgr.createLockForNewStorage(Config.getCfg().getUserName());
    }

    /**
     * Extracts and returns the version information from the specified
     * template signatures and instrument.
     *
     * @param instrName     name of the instrument for the template signatures
     * @param tmplSigs      template signatures whose version info is to be
     *                      extracted.
     *
     * @exception IOException if there was an I/O error reading the object.
     */
    public static TemplateVersionInfo[] getTemplateSignatureVersions(
        String instrName,
        TemplateSignature[] tmplSigs)
        throws IOException {

        // Instrument instr = InstrumentList.getInstance().getInstrument(instrName);
        Vector vec = new Vector();
        for (int j = 0; j < tmplSigs.length; j++) {
            TemplateVersionInfo templateInfo = new TemplateVersionInfo();
            templateInfo.setInstrumentName(instrName);
            templateInfo.setTemplateName(tmplSigs[j].getTemplateName());
            templateInfo.setVersion(tmplSigs[j].getVersion());
            vec.addElement(templateInfo);
        }

        TemplateVersionInfo[] versions = new TemplateVersionInfo[vec.size()];
        vec.copyInto(versions);
        return versions;
    }

    public static void recursiveMakeNameUnique(BusinessObject bo)
        throws ObjectIOException {
        Stack stk = new Stack();

        stk.push(bo);
        while (!stk.isEmpty()) {
            BusinessObject busObj = (BusinessObject)stk.pop();

            makeNameUnique(busObj);

            BusinessObject[] children = busObj.getBusObjChildren();
            for (int j = 0; j < children.length; j++) {
                stk.push(children[j]);
            }
        }
    }

    /**
     * Alters the name of the given BusinessObject to make it unique
     * within its containing directory.  If the name is modified, it
     * will be of the form "xxx-nnn", where "xxx" is the original name
     * and "nnn" is some sequence of digits.
     *
     * @param bo    BusinessObject whose name is to be made unique
     *
     * @exception ObjectIOException
     *                      if there was an I/O error reading the object.
     */
    public static void makeNameUnique(BusinessObject bo) throws ObjectIOException {
        Persistence objMgr = Persistence.getInstance();
        Media device = objMgr.getMediaFor(bo);
        DirectoryNode node = objMgr.getDirectoryFor(bo);
        BitSet used = new BitSet();
        Summary[] summs;
        Folder folder;

        RE nb_RE = null; // the regexp object
        REMatch nb_rem = null; // the regexp's result
        REMatch snb_rem = null;

        int slen = 0;
        int plen = 0;
        int maxUsed = -1;
        int smatch_len = 0;
        int match_len = 0;

        String prefix = null;
        String sprefix = null;

        if (device == null) {
            return; // XXX object not in memory???
        }

        String name = bo.getName();
        /*
         * This pattern says, that it can be matched with a string wich is ending
         * with a dash followed by 1 to 3 digits (0 thru 999)
         */
        String nb_pattern = "-\\d{1,3}$";

        try {
            nb_RE = new RE(nb_pattern);
        } catch (REException e) {
            stdlog_.error(e.getMessage(), e);
        }
        /*
         * we only are interrested in the four trailing characters of the name
         */
        if (name.length() < SUFFIX_LEN)
            match_len = name.length();
        else
            match_len = SUFFIX_LEN;

        nb_rem = nb_RE.getMatch(name, (name.length() - match_len));

        /*
         * IF the pattern has been found THEN
         */
        if (nb_rem != null) {
            plen = nb_rem.getStartIndex();
            prefix = name.substring(0, plen);
        } else {
            plen = name.length();
            prefix = name;
        }

        if (plen > 28) {
            /*JOptionPane.showMessageDialog(
                MainWindow.getPrincipalWindow(),
                "The name of the OB is to long for the duplicate."
                    + "\nIn order to get a \"unique\" name the original"
                    + "\nneeds to be truncated to 28 character!",
                "Warning message",
                JOptionPane.WARNING_MESSAGE);*/
            prefix = prefix.substring(0, 28);
        }

        folder = FolderFactory.getFolder(device, node);
        /*
         * an array with the summaries of all OB's ih this folder
         */
        summs = folder.getSummaryInformation();

        /*
         * loop through the array of summaries and
         *
         * find all objects with the same name as the current subject to
         * duplication.
         *
         * if this names have trailing numbers with up to 3 digits, set the
         * bit vectors position accordingly.
         */
        for (int j = 0; j < summs.length; j++) {
            String sname = summs[j].getName();

            if (sname.length() < SUFFIX_LEN)
                smatch_len = sname.length();
            else
                smatch_len = SUFFIX_LEN;

            if ((snb_rem = nb_RE.getMatch(sname, (sname.length() - smatch_len)))
                != null) {
                slen = snb_rem.getStartIndex();
                sprefix = sname.substring(0, slen);
            } else {
                slen = sname.length();
                sprefix = sname;
            }

            if (slen >= 0 && prefix.equals(sprefix)) {
                // extract "n" from "-n" suffix.
                int index = 0;
                if (sname.length() > sprefix.length()) {
                    index = new Integer(sname.substring(slen + 1)).intValue();
                    used.set(index);
                }
            }
            sprefix = null;
            snb_rem = null;
            slen = 0;
        }

        /*
         * create a new name, which is constructed out of the prefix of the name
         * and a free number indicated by the bitmask
         */
        if (used.size() > 0) {
            maxUsed = used.size() - 1;

            for (int j = 0; j <= maxUsed; j++) {
                if (!used.get(j)) {
                    bo.setName(prefix + "-" + j);
                    return;
                }
            }
            bo.setName(prefix + "-" + (maxUsed + 1));
        }
    }

    /**
     *
     *
     * @return -1   if user aborted the login <br>
     *          0   if the user has logged-in but we should download
     *                      observing runs, etc. <br>
     *          +1  if the user has logged-in and nothing more needs
     *                      to be done.
     * @exception ObjectIOException Object I/O Exception
     */
    public static int login(JFrame frm, StorageManager dbaseMgr)
        throws ObjectIOException {
        String t = OHSApplication.getShortDesc();
        LoginDialog loginDialog = new LoginDialog(frm, t + " login");
        AppConfig appcfg = AppConfig.getAppConfig();
        Config cfg = Config.getCfg();

        try {
            for (;;) {
                loginDialog.show();
                if (loginDialog.getUserChoice() == JOptionPane.OK_OPTION) {
                    int userID = loginDialog.getUserName();
                    if (userID == -1) {
                        JOptionPane.showMessageDialog(
                            frm,
                            "Username must be one or more digits",
                            "Login Error",
                            JOptionPane.WARNING_MESSAGE);
                        continue;
                    }
                    cfg.setUserName(userID);
                    cfg.setPassword(loginDialog.getPassword());

                    dbaseMgr.setUserId(cfg.getUserName());

                    File cacheFile =
                        new File(
                            appcfg.getCacheDir(),
                            loginDialog.getUserName() + ".dir");
                    if (hasSubdirs(cacheFile)) {
                        loginDialog.dispose();
                        lockMgr.lockLocalStorage(cfg.getUserName());
                        return +1;
                    } else if (
                        appcfg.isSuperUserEntitled()
                            || dbaseMgr.loginUser(cfg.getPassword())) {
                        loginDialog.dispose();
                        if (cfg.isInOperationsMode()) {
                            appcfg.setSuperUserEntitled(true);
                        }
                        return 0;
                    } else {
                        JOptionPane.showMessageDialog(
                            frm,
                            "Invalid username or password",
                            "Login Error",
                            JOptionPane.INFORMATION_MESSAGE);
                    }
                } else {
                    return -1;
                }
            }
        } catch (ObjectAuthorisationException e) {
            stdlog_.error("", e);
            ; // Leave as user support info.
            JOptionPane.showMessageDialog(
                null,
                new Object[] {
                    "Your username and password could not be verified"
                        + " and so details of",
                    "your Observing runs could not be downloaded. This"
                        + " is usually because",
                    "the server at ESO cannot be contacted, for some reason.",
                    " ",
                    "Check your Internet connection to ESO" + " and try again.",
                    "If error persists, contact ESO User Support.",
                    " ",
                    "Fatal error during initialisation" },
                "Fatal Error",
                JOptionPane.ERROR_MESSAGE);
            System.exit(1);
        } catch (ObjectIOException e) {
            ErrorMessages.announceIOError(null, e);
        }

        return -1;
    }

    /**
     * Setup the connection pool properties prior to its first use.
     * Note: P2PP requires a connection pool that allows connection re-use.
     */
    private void setupConnectionPool() {
        Properties p = new Properties();
        p.put(ConnectionPool.PoolSize, "20");
        p.put(ConnectionPool.ReopenAllowed, "T");
        if (!ConnectionPool.setInitProperties(p)) {
            System.err.println(
                "Warning: init properties ignored, connection pool already in use.");
        }

    }

    private static boolean hasSubdirs(File dir) {
        if (dir == null || !dir.exists() || !dir.isDirectory()) {
            return false;
        }

        String[] listing = dir.list();
        File file;

        if (listing == null) {
            return false;
        }

        for (int j = 0; j < listing.length; j++) {
            file = new File(dir, listing[j]);
            if (file.isDirectory()) {
                return true;
            }
        }

        return false;
    }

    public static void addSystemStatusListener(SystemStatusListener lnr) {
        SystemStatus.addSystemStatusListener(lnr);
    }

    public static void removeSystemStatusListener(SystemStatusListener lnr) {
        SystemStatus.removeSystemStatusListener(lnr);
    }

    /**
     * Informs listeners of a change in the system status.
     * No details of which property of the old/new value are given.
     */
    public static void fireSystemStatusEvent(int evtType, Object src) {
        SystemStatus.fireSystemStatusEvent(evtType, src);
    }

    public static boolean isCloneSelected() {
        return MainWindow.isCloneSelected();
    }

    public static StorageManager createStorageManager(Media device)
        throws ObjectIOException {
        AppConfig appcfg = AppConfig.getAppConfig();

        if (appcfg.shouldUseAppServer()) {
            return new AuthenticatingStorageMgr(
                new RmiLocalManager(device, appcfg.getAppServerUrl()));
        } else {
            StorageManager stMgr;

            if (device.equals(Media.PHASE1_DB)) {
                stMgr = new OpcDbaseMgr();
            } else if (device.equals(Media.PHASE2_DB)) {
                boolean checkIPVersion =
                    AppConfig.getAppConfig().getBoolean(
                        OHSKeys.IPVersionsingEnsureCorrectIPVersionOnOBCheckin);
                DbaseMgr dbm = new DbaseMgr();
                dbm.setEnforceIPVersionCheck(checkIPVersion);
                stMgr = new EVMStorageMgr(dbm, new OpcDbaseMgr());
            } else {
                throw new IllegalArgumentException("Unknown device: " + device);
            }

            return new AuthenticatingStorageMgr(new ProtectingStorageMgr(stMgr));
        }
    }

    /**
     * One of a pair of methods to prevent concurrent access to local storage.
     * We use a strange convention (ie the absence of a file) to indicate
     * that a user subdir is locked.  This is because File.delete() is the
     * nearest things we have (in JDK 1.1) to an atomic test-and-set file
     * operation.  JDK 1.2 and beyond have createNewFile().
     *
     * <p>
     * This kind of locking is not atomic and is unsatisfactory in many ways
     * but it's better than nothing and we give the user the option to
     * override it.  If you can do better, please do!
     */
    public static class LockMgr {

        private AppConfig appcfg = AppConfig.getAppConfig();
        private File cacheDirFile = new File(appcfg.getCacheDir());
        private String ppid;
        private static String lck_prefix;

        /** amchavan, 20-Dec-2001 */
        private static Logger stdlog_ = Logger.getLogger(LockMgr.class);

        LockMgr() {
            ppid = System.getProperty("runtime.ppid");
        }
        /*
                LockMgr(String l_ppid)
                {
                    ppid = l_ppid;
                }
        */

        /**
         * A hashtable to keep track of the local storage areas we have
         * locked. Normally we only have one locked at a time but during
         * ReloginAction, for a short period, we have both old and
         * new cache dirs locked.
             *
             * This method does nothing upon every attempt to re-login, using the
             * "Login as" option from the main menu, with the same userID.
         */
        private Hashtable locks_ = new Hashtable();

        public void lockLocalStorage(int userId) throws ObjectIOException {
            lck_prefix = "lockinfo." + userId;

            if (userId == loc_userID) {
                stdlog_.info("lockLocalStorage: same userID");
                return;
            } else {
                stdlog_.info("lockLocalStorage: different userID");
                loc_userID = userId;
            }

            File unlockedFile = new File(cacheDirFile, "unlocked." + userId);
            // File infoFile = new File(cacheDirFile, lck_prefix + "." + ppid);
            /*
             * For users, who migrate from V2.1 to V2.2 there need to be a check,
             * for a missing unlocked file. Otherwise p2pp would assume, that
             * the user was logged in just because the unlocked-file is missing.
             */
            FilenameFilter lck_filter = new FilenameFilter() {
                public boolean accept(File dir, String name) {
                    if (name.startsWith(lck_prefix))
                        return true;
                    return false;
                }
            };
            /*
             * IF no unlockedFile exists but a lockinfoFile, then assume, that
             * somebody is already logged in with this userId
             * IF neither an unlockedFile nor a lockinfo file exists, that assume
             * that that the user is migrating from V2.1 to V2.2 or lost the
             * lockinfo File for some other reason.
             */
            if (!unlockedFile.delete()
                && cacheDirFile.list(lck_filter).length != 0) {
                String lockedBy = "";
                String[] lockFiles = cacheDirFile.list(lck_filter);
                if (lockFiles.length > 0) {
                    lockedBy =
                        new File(cacheDirFile + File.separator + lockFiles[0])
                            .getAbsolutePath();
                }

                JOptionPane.showMessageDialog(
                    MainWindow.getPrincipalWindow(),
                    "The system is apparently already in use for this user ID"
                        + "\nConcurrent use for a user ID is not possible.\n"
                        + "\nIf you are sure this system and user ID are not in-use"
                        + "\nat this time, please remove the lock file:"
                        + "\n"
                        + lockedBy
                        + "\nand restart the application."
                        + "\n\nCannot continue!",
                    "Warning message",
                    JOptionPane.ERROR_MESSAGE);

                stdlog_.fatal("UserID " + userId + " is already in use - exiting");
                System.exit(0);
            }

            markAsLocked(userId);
            createInfoFile(userId);
        }

        private void markAsLocked(int userId) {
            Long idLong = new Long(userId);
            locks_.put(idLong, idLong);
        }

        private void markAsUnlocked(int userId) {
            Long idLong = new Long(userId);
            locks_.remove(idLong);
        }

        private boolean haveLocked(int userId) {
            Long idLong = new Long(userId);
            return locks_.containsKey(idLong);
        }

        private void createInfoFile(int userId) {
            File infoFile = new File(cacheDirFile, "lockinfo." + userId + "." + ppid);
            try {
                infoFile.delete();
                FileIOUtils.stringToFile(
                    System.getProperty("user.name"),
                    infoFile.getAbsolutePath());
            } catch (IOException e) {
                stdlog_.error("", e);
            }
        }

        public void unlockLocalStorage(int userId) {
            File unlockedFile = new File(cacheDirFile, "unlocked." + userId);
            File infoFile = new File(cacheDirFile, "lockinfo." + userId + "." + ppid);

            if (haveLocked(userId)) {
                infoFile.renameTo(unlockedFile);
                markAsUnlocked(userId);
            }
        }

        public void createLockForNewStorage(int userId) {
            createInfoFile(userId);
            markAsLocked(userId);
        }
    }

    public static void chk4cache_create(String cacheDir) {
        if (cacheCreatePopedUp == false) {
            if (LocalDirMgr.cacheDirsCreated() == true) {
                JOptionPane.showMessageDialog(
                    MainWindow.getPrincipalWindow(),
                    "The system just created the cache directory"
                        + "\nin "
                        + cacheDir,
                    "Warning message",
                    JOptionPane.WARNING_MESSAGE);
            }
            cacheCreatePopedUp = true;
        }
    }

    /*
     * set window dimensions to smaller than screen size
     *
     * @param frame     window to resize
     * @return new screen dimension object
     */
    public static Dimension setScreenSize(JFrame frame) {
        frame.pack();
        Dimension screen =
            Toolkit.getDefaultToolkit().getScreenSize();
        
        Dimension window = frame.getPreferredSize();
        int maxWinHeight = (int) (screen.height * maxSizeRatio);
        int maxWinWidth = (int) (screen.width * maxSizeRatio);
        if (window.height > maxWinHeight) {
            window.height = maxWinHeight;
        }
        if (window.width > maxWinWidth) {
            window.width = maxWinWidth;
        }
        frame.setSize(window);
        return window;
    }
}

