package org.eso.ohs.phase2.visiplot;

/**
 * Base class for displaying a javachart.beans.chart.ChartBean in a JPanel.
 * This allows for scrolling/resizing in a JScrollPane.
 * In addition, the class provides controls for seting size, font, dimension,
 * etc for the underlying chart bean object.
 *
 * @author Nick Kornweibel for ESO
 */

import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;

import javachart.beans.chart.ChartBean;
import javachart.chart.Plotarea;

import javax.swing.JPanel;

import org.eso.ohs.core.utilities.MsgManager;

public class ChartPanel extends JPanel {

    private ChartBean chartBean_ = null;

    /**
     * Create a ChartPanel displaying on the ChartBean passed.
     */

    public ChartPanel(ChartBean cb) {
        chartBean_ = cb;
    }

    /**
     * Set the preferred size of the ChartPanel - these settings are
     * set in the ChartBean as well as used to set the size of this Panel.
     * @param width desired
     * @param height desired
     */

    public void setChartSize(int width, int height) {
        chartBean_.setPreferredSize(width, height);
        setPreferredSize(new Dimension(width, height));
        chartBean_.setSize(width, height);
    }
   
    /**
     * update/paint the chart
     */

    public void update(Graphics g) {
        paint(g);
    }

    /**
     * paint the chart
     */

    public void paint(Graphics g) {
        chartBean_.getChart().paint(this, g);
    }

    /**
     * Set all fonts in the chart to the given Font
     */

    public void setAllFonts(Font f) {
        // explicit class path required as there are two
        // Chart classes available in scope (javachart.chart.Chart
        // and javachart.beans.chart.Chart).
        javachart.chart.Chart chart = chartBean_.getChart();
        assert (chart != null): MsgManager.errInvariant("chart null");
        chart.getBackground().setTitleFont(f);
        chart.getXAxis().setLabelFont(f);
        chart.getYAxis().setLabelFont(f);
        chart.getXAxis().setTitleFont(f);
        chart.getYAxis().setTitleFont(f);
    }

    /**
     * Set the Lower Left (llX and llY) corner position and the upper right
     * (urX, urY) corner position of the plot within the panel. The values
     * are to vary between 0.0 (0 on the axis) to 1.0 max value on that axis.
     * @param llX the X coordinate control for the lower left corner
     * @param llY the Y coordinate control for the lower left corner
     * @param urX the X coordinate control for the upper right corner
     * @param urY the Y coordinate control for the upper right corner
     */

    public void setPlotPosition(double llX, double llY,
            double urX, double urY) {
    	
    	assert (llX > 0): MsgManager.errPrecondition("llx = " + llX);
    	assert (llY > 0): MsgManager.errPrecondition("lly = " + llY);
    	assert (urX > 0): MsgManager.errPrecondition("urx = " + urX);
    	assert (urY > 0): MsgManager.errPrecondition("ury = " + urY);
    	
        Plotarea plot = chartBean_.getChart().getPlotarea();
        plot.setLlX(llX);
        plot.setLlY(llY);
        plot.setUrX(urX);
        plot.setUrY(urY);
    }
}
