package org.eso.ohs.phase2.visiplot;

/*
 * Static methods for Chart image processing - chart printing, saving charts
 * to JPEG, GIF, creating Image objects from ChartPanels, etc.
 * 
 * @author Nick Kornweibel for ESO.
 */

import java.awt.Graphics;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.swing.JComponent;

public class ChartUtils {

    /**
     * Create an Image from a JComponent.
     * @param JComponent source from which the image will be generated.
     * @return the Image component created from the JComponent.
     */

    public static Image getImageFromComponent(JComponent src) { 
        // create a blank image
        // User a BufferedImage instead of a standard Image.
        BufferedImage rc = new BufferedImage(src.getWidth(), src.getHeight(), BufferedImage.TYPE_INT_RGB);
        // VERY SLOW in Java 1.4: Image rc = src.createImage(src.getWidth(), src.getHeight());
        // get the graphics for that image
        Graphics graphic = rc.getGraphics();
        // set the graphics to the size of the src (do we need this?).
        graphic.setClip(new Rectangle(src.getSize()));
        // paint the Component to the Image
        src.paint(graphic);
        return rc;
    }

    /**
     * Create a GIF file image of the specified component
     * in the specified path.
     * @param file path to the gif file to be created.
     * @param component whose image is to be saved as a GIF format file.
     * @throws IOException on io exception writing file.
     */

    public static void saveComponentToGIFFile(File gifPath, JComponent src)
            throws IOException {

        FileOutputStream fos = new FileOutputStream(gifPath);
        Image img = getImageFromComponent(src);
        GifMaker gm = new GifMaker(fos, img);
        gm.generate();
        byte[] output = gm.getByteArray();
        fos.write(output);
        fos.flush();
        fos.close();
    }
}
