package org.eso.ohs.phase2.visiplot;

/**
 * @version $Revision: 1.3 $
 * @author  Nick Kornweibel for ESO. Created on July 31, 2001, 10:45 AM
 * <br>ChangeLog: cmavros 26/09/01 Add Time Interval menu option 
 */

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.util.ArrayList;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerModel;
import javax.swing.SpinnerNumberModel;

import org.eso.ohs.phase2.actions.AutoColorAction;

/**
 * VisiPlot panel managing the chart color options
 * @author gdonino
 *
 */
public class ColorOptionsPanel extends JPanel {

	private ChartColorItem airMass;
	private ChartColorItem moonDist;
	private ChartColorItem fli;
	private ChartColorItem sun;
	private ChartColorItem timeInterval;
	private ChartColorItem execTime;
	private ChartColorItem sidereal;
    
	private ArrayList items;
  //  private ArrayList items = new ArrayList();

    /**
     * Creates new form PlotOptionsPanel
     */

    public ColorOptionsPanel() {
        initComponents ();
    }

    /**
     * This method is called from within the constructor to
     * initialize the form.
     */
    
    public ChartColorItem[] getChartColorItems(){
    	ChartColorItem[] result = {airMass, moonDist, fli, sun, timeInterval, execTime, sidereal};
    	
    	return result;
    }
    private void initComponents() {
    	//As no charts are displaying labels, I think it would be better 
    	// to turn off the labels color
    	// example:
    	// airMass = new ChartColorItem("air mass", true, false);
    	
    	airMass = new ChartColorItem("air mass", true, true);
    	moonDist = new ChartColorItem("moon distance", true, true);
    	fli = new ChartColorItem("fractional lunar ill.", true, true);
    	sun = new ChartColorItem("sun angle", true, true);
    	timeInterval = new ChartColorItem("time intervals", true, true);
    	execTime = new ChartColorItem("execution time", true, true);
    	sidereal = new ChartColorItem("st time intervals", true, true);
    	
    	items = new ArrayList();
    	items.add(airMass);
    	items.add(moonDist);
    	items.add(fli);
    	items.add(sun);
    	items.add(execTime);
    	items.add(timeInterval);
    	items.add(sidereal);

        setLayout(new BorderLayout());
        JPanel northPanel = new JPanel();
        northPanel.setLayout(new GridLayout(1, 4));
       
        add(northPanel, BorderLayout.NORTH);
       
        /*
         *TODO find better names for the columns
         */ 
        northPanel.add(new JLabel ("chart name"));
        northPanel.add(new JLabel(" plotting line"));
        northPanel.add(new JLabel(" plotting area"));
        northPanel.add(new JLabel(" chart labels"));
        JPanel centerPanel = new JPanel();
        centerPanel.setLayout(new GridLayout(7,4));
        add(centerPanel, BorderLayout.CENTER);
      
        for (int i = 0; i < items.size(); i++){
        	ChartColorItem item = (ChartColorItem) items.get(i);
        	JComponent[] components = item.getComponents();
        	for (int j = 0; j < components.length; j++){
        		centerPanel.add(components[j]);
        	}
        } 
        
        JPanel southPanel = new JPanel();
        southPanel.setLayout(new GridLayout(1, 4));
        JSpinner spinner = createJSpinner();
        spinner.setSize(20, 20);
        spinner.setToolTipText("Blend factor");
        JButton autoColButton = new JButton("auto");
        autoColButton.addActionListener(new AutoColorAction(items, spinner));
        /*
         * TODO find an understandable tootTip text
         */
        autoColButton.setToolTipText("it makes all the first color a brighter version \n" +
        							 "of the second color and makes all the labels \n" +
        							 "dark blue");
        southPanel.add(spinner);
        southPanel.add(autoColButton);
        add(southPanel, BorderLayout.SOUTH);
       
  }

	private JSpinner createJSpinner() {
		
        SpinnerModel spinnerModel = new SpinnerNumberModel(100, //initial value
                                       0, //min
                                       255, //max
                                       1); //step
        
        JSpinner spinner = new JSpinner(spinnerModel);
        spinner.setEditor(new JSpinner.NumberEditor(spinner, "#"));
		return spinner;
	}

	public ChartColorItem getAirMass() {
		return airMass;
	}

	public ChartColorItem getExecTime() {
		return execTime;
	}

	public ChartColorItem getFli() {
		return fli;
	}

/*	public ArrayList getItems() {
		return items;
	}
*/
	public ChartColorItem getMoonDist() {
		return moonDist;
	}

	public ChartColorItem getSidereal() {
		return sidereal;
	}

	public ChartColorItem getSun() {
		return sun;
	}

	public ChartColorItem getTimeInterval() {
		return timeInterval;
	}

	public void setAirMass(ChartColorItem airMass) {
		this.airMass = airMass;
	}

	public void setExecTime(ChartColorItem execTime) {
		this.execTime = execTime;
	}

	public void setFli(ChartColorItem fli) {
		this.fli = fli;
	}

	/*public void setItems(ArrayList items) {
		this.items = items;
	}*/

	public void setMoonDist(ChartColorItem moonDist) {
		this.moonDist = moonDist;
	}

	public void setSidereal(ChartColorItem sidereal) {
		this.sidereal = sidereal;
	}

	public void setSun(ChartColorItem sun) {
		this.sun = sun;
	}

	public void setTimeInterval(ChartColorItem timeInterval) {
		this.timeInterval = timeInterval;
	}
	
}

