package org.eso.ohs.persistence;

import java.util.EventObject;


/**
 * Encapsulates information describing changes in the selection for
 * a FolderGridView and is used to notify listeners of the change
 * <p>
 * $Id: ObjectSelectionEvent.java,v 1.1 2005/02/11 09:51:57 tcanavan Exp $
 * <br>
 * @version $Revision: 1.1 $
 * @author Bob Kemp
 */
public class ObjectSelectionEvent extends EventObject {

    /** id value specifying that no object of the given type is selected */
    public final static long NO_OBJECT = -1;

    /**
     * external media where the object resides, e.g.&nbsp;
     * local storage, RDBMS, etc
     */
    private Media device_;

    /** id of the Business Object which the event is to take place on */
    private long id_;

    /** type of the object that is now selected */
    private Class objType_;

    /**
     * In MainWindow.Views singleWindow mode, should the details for this
     * type of object be brought to the front?
     */
    private boolean bringToTheFront_;

    /** Should a details view for the object selected be made visible? */
    private boolean forceVisible_;

    /** The number of rows in a table */
    int rowCount_;

    /**
     * Constructor for ObjectSelectionEvent
     *
     * @param src               ource
     * @param device            edium on which the object resides
     * @param id                he object that has changed
     * @param objType           object type
     * @param forceVisible      forceVisible
     * @param bringToTheFront   bringToTheFront
     * @param rowCount          row count
     */
    public ObjectSelectionEvent(Object src, Media device, long id,
            Class objType, boolean forceVisible,
            boolean bringToTheFront, int rowCount) {
        super(src);
        device_ = device;
        id_ = id;
        objType_ = objType;
        forceVisible_ = forceVisible;
        bringToTheFront_ = bringToTheFront;
        rowCount_ = rowCount;
    }

    /**
     * Retrieves media type
     * @return Device where Business object will be stored
     */
    public Media getMedia() {
        return device_;
    }

    /**
     * Returns the numbers of rows in a JTable
     * @return The number of rows in the JTable
     */
    public int getRowCount() {
        return rowCount_;
    }

    /**
     * Retrieves the id of the BusinessObject selected
     *
     * @return id of the BusinessObject
     */
    public long getObjectId() {
        return id_;
    }

    /**
     * Retrieves the type of the BusinessObject selected
     *
     * @return type of the BusinessObject
     */
    public Class getObjectClass() {
        return objType_;
    }

    /**
     * Returns true if the selected BusinessObject should be made visible
     *
     * @return true if the object should be made visible, false otherwise
     */
    public boolean shouldMakeVisible() {
        return forceVisible_;
    }

    /**
     * Returns true if objType_ type of objects are visible in the
     * FolderGridView generating this event
     *
     * @return true if the object summary is visible, false otherwise
     */
    public boolean shouldBringToTheFront() {
        return bringToTheFront_;
    }

    public String paramString() {
        return "id=" + id_ + ",type=" + objType_ + ",src=" + getSource();
    }

    public String toString() {
        return getClass().getName() + "[" + paramString() + "]";
    }
}

